@@ -1,6 +1,6 @@
 #' Analysis: Randomized block design by glm
 #' @description Statistical analysis of experiments conducted in a randomized block design using a generalized linear model. It performs the deviance analysis and the effect is tested by a chi-square test. Multiple comparisons are adjusted by Tukey.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param trat Numerical or complex vector with treatments
@@ -13,8 +13,8 @@
 #' @param geom Graph type (columns, boxes or segments)
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param sup Number of units above the standard deviation or average bar on the graph
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
+#' @param xlab Treatments name (this argument uses the \emph{parse} function)
 #' @param textsize Font size
 #' @param labelsize Label size
 #' @param fill Defines chart color (to generate different colors for different treatments, define fill = "trat")
@@ -58,6 +58,9 @@ DBC.glm=function(trat,
                  posi="top",
                  point="mean_sd",
                  angle.label=0){
+  ylab=parse(text=gsub(" ","~",ylab))
+  xlab=parse(text=gsub(" ","~",xlab))
+
   if(angle.label==0){hjust=0.5}else{hjust=0}
   requireNamespace("emmeans")
   # requireNamespace("stringr")
@@ -160,15 +163,15 @@ DBC.glm=function(trat,
                    fill=fill,shape=21,size=5)}}
       grafico=grafico+
         theme+
-        ylab(ylab)+
-        xlab(xlab)+
+        ylab(parse(text=ylab))+
+        xlab(parse(text=xlab))+
         theme(text = element_text(size=textsize,color="black", family = family),
               axis.text = element_text(size=textsize,color="black", family = family),
               axis.title = element_text(size=textsize,color="black", family = family),
               legend.position = "none")
       if(angle !=0){grafico=grafico+
         theme(axis.text.x=element_text(hjust = 1.01,angle = angle))}
-      grafico=as.list(grafico)
+      # grafico=as.list(grafico)
       print(grafico)
     }
   }
@@ -263,16 +266,16 @@ DBC.glm=function(trat,
                    fill=fill,shape=21,size=5)}}
       grafico=grafico+
         theme+
-        ylab(ylab)+
-        xlab(xlab)+
+        ylab(parse(text=ylab))+
+        xlab(parse(text=xlab))+
         theme(text = element_text(size=textsize,color="black", family = family),
               axis.text = element_text(size=textsize,color="black", family = family),
               axis.title = element_text(size=textsize,color="black", family = family),
               legend.position = "none")
       if(angle !=0){grafico=grafico+
         theme(axis.text.x=element_text(hjust = 1.01,angle = angle))}
-      grafico=as.list(grafico)
-      print(grafico)
+      # grafico=as.list(grafico)
+      grafico
     }
   }
 
