@@ -1,5 +1,5 @@
 #' Analysis: DBC experiments in double factorial
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @description Analysis of an experiment conducted in a randomized block design in a double factorial scheme using analysis of variance of fixed effects.
@@ -11,7 +11,7 @@
 #' @param homog Homogeneity test of variances (\emph{default} is Bartlett)
 #' @param mcomp Multiple comparison test (Tukey (\emph{default}), LSD, Scott-Knott and Duncan)
 #' @param quali Defines whether the factor is quantitative or qualitative (\emph{qualitative})
-#' @param names.fat Name of factors
+#' @param names.fat Name of factors (this argument uses the \emph{parse} function)
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
 #' @param transf Applies data transformation (default is 1; for log consider 0; `angular` for angular transformation)
@@ -21,9 +21,7 @@
 #' @param grau21 Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with n levels of factor 1, in the case of interaction f1 x f2 and qualitative factor 1 and quantitative factor 2.
 #' @param geom Graph type (columns or segments (For simple effect only))
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
-#' @param xlab.factor Provide a vector with two observations referring to the x-axis name of factors 1 and 2, respectively, when there is an isolated effect of the factors. This argument uses `parse`.
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
 #' @param posi Legend position
 #' @param legend Legend title name
 #' @param ylim y-axis scale
@@ -42,6 +40,8 @@
 #' @param angle.label label angle
 #' @param width.column Width column if geom="bar"
 #' @param width.bar Width errorbar
+#' @param print.on Print output
+#' @param plot.on Plot output
 #' @note The order of the chart follows the alphabetical pattern. Please use `scale_x_discrete` from package ggplot2, `limits` argument to reorder x-axis. The bars of the column and segment graphs are standard deviation.
 #' @return The table of analysis of variance, the test of normality of errors (Shapiro-Wilk, Lilliefors, Anderson-Darling, Cramer-von Mises, Pearson and Shapiro-Francia), the test of homogeneity of variances (Bartlett or Levene), the test of independence of Durbin-Watson errors, the test of multiple comparisons (Tukey, LSD, Scott-Knott or Duncan) or adjustment of regression models up to grade 3 polynomial, in the case of quantitative treatments. The column chart for qualitative treatments is also returned.
 #' @note The function does not perform multiple regression in the case of two quantitative factors.
@@ -78,19 +78,15 @@
 #' #================================================
 #' library(AgroR)
 #' data(cloro)
-#' attach(cloro)
-#' FAT2DBC(f1, f2, bloco, resp, ylab="Number of nodules", legend = "Stages")
-#' FAT2DBC(f1, f2, bloco, resp, mcomp="sk", ylab="Number of nodules", legend = "Stages")
+#' with(cloro,FAT2DBC(f1, f2, bloco, resp, ylab="Number of nodules"))
+#' with(cloro,FAT2DBC(f1, f2, bloco, resp, mcomp="sk", ylab="Number of nodules"))
 #' #================================================
 #' # Example covercrops
 #' #================================================
 #' library(AgroR)
 #' data(covercrops)
-#' attach(covercrops)
-#' FAT2DBC(A, B, Bloco, Resp, ylab=expression("Yield"~(Kg~"100 m"^2)),
-#' legend = "Cover crops")
-#' FAT2DBC(A, B, Bloco, Resp, mcomp="sk", ylab=expression("Yield"~(Kg~"100 m"^2)),
-#' legend = "Cover crops")
+#' with(covercrops,FAT2DBC(A, B, Bloco, Resp, ylab="Yield (Kg 100 m^2)"))
+#' with(covercrops,FAT2DBC(A, B, Bloco, Resp, mcomp="sk", ylab="Yield (Kg 100 m^2)"))
 
 FAT2DBC=function(f1,
                  f2,
@@ -111,8 +107,6 @@ FAT2DBC=function(f1,
                  geom = "bar",
                  theme = theme_classic(),
                  ylab = "Response",
-                 xlab = "",
-                 xlab.factor=c("F1","F2"),
                  legend = "Legend",
                  fill = "lightblue",
                  angle = 0,
@@ -130,8 +124,12 @@ FAT2DBC=function(f1,
                  color = "rainbow",
                  posi = "right",
                  ylim = NA,
-                 angle.label=0){
+                 angle.label=0,
+                 print.on=TRUE,
+                 plot.on=TRUE){
   if(angle.label==0){hjust=0.5}else{hjust=0}
+  lab.factor=c(gsub(" ","~",names.fat[1]),gsub(" ","~",names.fat[2]))
+  ylab=parse(text=gsub(" ","~",ylab))
   requireNamespace("crayon")
   requireNamespace("ggplot2")
   requireNamespace("nortest")
@@ -212,16 +210,17 @@ FAT2DBC=function(f1,
     scale_x_continuous(breaks=1:length(respad))+
     theme_classic()+theme(axis.text.y = element_text(size=textsize),
                           axis.text.x = element_blank())+
-    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",size=1)
-
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",linewidth=1)
+  if(print.on==TRUE){
+    cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Normality of errors")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   normal=data.frame(Method=paste(norm1$method,"(",names(norm1$statistic),")",sep=""),
                     Statistic=norm1$statistic,
                     "p-value"=norm1$p.value)
   rownames(normal)=""
-  print(normal)
+  if(print.on==TRUE){
+    print(normal)
   cat("\n")
 
   message(if(norm1$p.value>0.05){
@@ -229,12 +228,13 @@ FAT2DBC=function(f1,
       else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, errors do not follow a normal distribution"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Homogeneity of Variances")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   homoge=data.frame(Method=method,
                     Statistic=statistic,
                     "p-value"=phomog)
   rownames(homoge)=""
-  print(homoge)
+  if(print.on==TRUE){
+    print(homoge)
   cat("\n")
 
   message(if(homog1$p.value[1]>0.05){
@@ -242,13 +242,14 @@ FAT2DBC=function(f1,
       else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, the variances are not homogeneous"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Independence from errors")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   indepe=data.frame(Method=paste(indep$method,"(",
                                  names(indep$statistic),")",sep=""),
                     Statistic=indep$statistic,
                     "p-value"=indep$p.value)
   rownames(indepe)=""
-  print(indepe)
+  if(print.on==TRUE){
+    print(indepe)
   cat("\n")
 
   message(if(indep$p.value>0.05){
@@ -265,30 +266,33 @@ FAT2DBC=function(f1,
   cat("\n")
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Analysis of Variance")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   anava1=as.matrix(data.frame(anava))
   colnames(anava1)=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
   rownames(anava1)=c(names.fat[1],names.fat[2],"Block",
                      paste(names.fat[1],"\u00D7",names.fat[2]),"Residuals")
-  print(anava1,na.print = "")
+  if(print.on==TRUE){
+    print(anava1,na.print = "")
   cat("\n")
   if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 &&homog1$p.value<0.05){
     message("\n Your analysis is not valid, suggests using a non-parametric test and try to transform the data\n")}else{}
   if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){
-    message("\n Your analysis is not valid\n")}else{}
+    message("\n Your analysis is not valid\n")}else{}}
 
   if (a$`Pr(>F)`[4] > alpha.f){
-    cat(green(bold("-----------------------------------------------------------------\n")))
+    if(print.on==TRUE){
+      cat(green(bold("-----------------------------------------------------------------\n")))
     cat(green(bold("No significant interaction")))
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     fatores <- data.frame(Fator1 = factor(fator1), Fator2 = factor(fator2))
     fatoresa <- data.frame(Fator1 = fator1a, Fator2 = fator2a)
     graficos=list(1,2,3)
 
     for (i in 1:2) {if (a$`Pr(>F)`[i] <= alpha.f){
-      cat(green(bold("\n-----------------------------------------------------------------\n")))
+      if(print.on==TRUE){
+        cat(green(bold("\n-----------------------------------------------------------------\n")))
       cat(bold(names.fat[i]))
-      cat(green(bold("\n-----------------------------------------------------------------\n")))
+      cat(green(bold("\n-----------------------------------------------------------------\n")))}
       if(quali[i]==TRUE){
       if(mcomp=="tukey"){
         letra <- TUKEY(b, colnames(fatores[i]), alpha=alpha.t)
@@ -316,8 +320,9 @@ FAT2DBC=function(f1,
           if(mcomp=="sk"){"Scott-Knott"}else{
             if(mcomp=="lsd"){"LSD-Fischer"}else{
               if(mcomp=="duncan"){"Duncan"}}}}
-        cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
-        print(letra1)
+        if(print.on==TRUE){
+          cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
+        print(letra1)}
       ordem=unique(as.vector(unlist(fatores[i])))
       #=====================================================
       if(point=="mean_sd"){desvio=tapply(response, c(fatores[i]), sd, na.rm=TRUE)[ordem]}
@@ -340,12 +345,12 @@ FAT2DBC=function(f1,
 
       if(geom=="bar"){grafico=ggplot(dadosm,aes(x=trats,
                                                 y=media))
-      if(fill=="trat"){grafico=grafico+geom_col(aes(fill=trats),
+      if(fill[1]=="trat"){grafico=grafico+geom_col(aes(fill=trats),
                                                 color=1,width = width.column)}
-      else{grafico=grafico+geom_col(aes(fill=trats),fill=fill,color=1,width = width.column)}
+      else{grafico=grafico+geom_col(aes(fill=trats),fill=fill[1],color=1,width = width.column)}
       grafico=grafico+theme+
-        ylab(ylab)+
-        xlab(parse(text = xlab.factor[i]))
+        ylab(parse(text=ylab))+
+        xlab(parse(text = lab.factor[i]))
       if(errorbar==TRUE){grafico=grafico+
         geom_text(aes(y=media+sup+if(sup<0){-desvio}else{desvio},
                       label=letra),family=family,angle=angle.label, hjust=hjust,size=labelsize)}
@@ -366,13 +371,13 @@ FAT2DBC=function(f1,
       if(geom=="point"){grafico=ggplot(dadosm,
                                        aes(x=trats,
                                            y=media))
-      if(fill=="trat"){grafico=grafico+
+      if(fill[1]=="trat"){grafico=grafico+
         geom_point(aes(color=trats),size=5)}
       else{grafico=grafico+
         geom_point(aes(color=trats),fill="gray",pch=21,color="black",size=5)}
       grafico=grafico+theme+
-        ylab(ylab)+
-        xlab(parse(text = xlab.factor[i]))
+        ylab(parse(text=ylab))+
+        xlab(parse(text = lab.factor[i]))
       if(errorbar==TRUE){grafico=grafico+
         geom_text(aes(y=media+sup+if(sup<0){-desvio}else{desvio},
                       label=letra,size=labelsize),
@@ -394,29 +399,35 @@ FAT2DBC=function(f1,
       if(CV==TRUE){grafico=grafico+labs(caption=paste("p-value ", if(a$`Pr(>F)`[i]<0.0001){paste("<", 0.0001)}
                                                       else{paste("=", round(a$`Pr(>F)`[i],4))},"; CV = ",
                                                       round(abs(sqrt(a$`Mean Sq`[5])/mean(resp))*100,2),"%"))}
-      grafico=grafico
       if(color=="gray"){grafico=grafico+scale_fill_grey()}
-      # print(grafico)
-      cat("\n\n")
+      if(length(fill)>=2){grafico=grafico+scale_fill_manual(values=fill)}
+      if(plot.on==TRUE){
+        print(grafico$plot)}
       }
       if(quali[i]==FALSE){
         dose=as.vector(unlist(fatoresa[i]))
         grafico=polynomial(dose,
                            resp,
                            grau = grau[i],
-                           ylab=ylab,
-                           xlab=parse(text = xlab.factor[i]),
+                           ylab=parse(text=ylab),
+                           xlab=parse(text = lab.factor[i]),
                            posi=posi,
                            theme=theme,
                            textsize=textsize,
                            point=point,
                            family=family,
                            SSq=ab$`Sum Sq`[5],
-                           DFres = ab$Df[5])
+                           DFres = ab$Df[5],
+                           print.on = print.on,
+                           plot.on = FALSE)
+        if(plot.on==TRUE){
+          print(grafico$plot)}
         grafico=grafico[[1]]}
     graficos[[i+1]]=grafico}}
     graficos[[1]]=residplot
-    if(a$`Pr(>F)`[1]>=alpha.f && a$`Pr(>F)`[2] <alpha.f){
+
+    if(print.on==TRUE){
+  if(a$`Pr(>F)`[1]>=alpha.f && a$`Pr(>F)`[2] <alpha.f){
   cat(green(bold("\n-----------------------------------------------------------------\n")))
     cat(green("Isolated factors 1 not significant"))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
@@ -436,15 +447,16 @@ FAT2DBC=function(f1,
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       cat(green("Isolated factors not significant"))
       cat(green(bold("\n-----------------------------------------------------------------\n")))
-      print(tapply(response,list(fator1,fator2),mean, na.rm=TRUE))}
+      print(tapply(response,list(fator1,fator2),mean, na.rm=TRUE))}}
   }
   if (a$`Pr(>F)`[4]  <= alpha.f) {
-    cat(green(bold("-----------------------------------------------------------------\n")))
+    if(print.on==TRUE){
+      cat(green(bold("-----------------------------------------------------------------\n")))
     cat(green(bold("\nSignificant interaction: analyzing the interaction\n")))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     cat("\n-----------------------------------------------------------------\n")
     cat("Analyzing ", names.fat[1], " inside of each level of ",names.fat[2])
-    cat("\n-----------------------------------------------------------------\n")
+    cat("\n-----------------------------------------------------------------\n")}
     des1<-aov(resp~ bloco + Fator2/Fator1)
     l1<-vector('list',nv2)
     names(l1)<-names(summary(Fator2))
@@ -464,7 +476,8 @@ FAT2DBC=function(f1,
                          paste(names.fat[1],"\u00D7",names.fat[2],"+",names.fat[1]),
                          paste("  ",rn),"Residuals")
 
-    print(des1.tab)
+    if(print.on==TRUE){
+      print(des1.tab)}
     desdobramento1=des1.tab
     if(quali[1]==TRUE & quali[2]==TRUE){
     if (mcomp == "tukey"){
@@ -545,10 +558,11 @@ FAT2DBC=function(f1,
         letra=datag$letra}
     }
 
-    cat("\n-----------------------------------------------------------------\n")
+    if(print.on==TRUE){
+      cat("\n-----------------------------------------------------------------\n")
     cat("Analyzing ", names.fat[2], " inside of the level of ",names.fat[1])
     cat("\n-----------------------------------------------------------------\n")
-    cat("\n")
+    cat("\n")}
     des2<-aov(resp~ bloco + Fator1/Fator2)
 
     l2<-vector('list',nv1)
@@ -569,7 +583,8 @@ FAT2DBC=function(f1,
     rownames(des2.tab)=c("Block",names.fat[1],
                          paste(names.fat[1],"\u00D7",names.fat[2],"+",names.fat[2]),
                          paste("  ",rn),"Residuals")
-    print(des2.tab)
+    if(print.on==TRUE){
+      print(des2.tab)}
     desdobramento2=des2.tab
 
     if(quali[1]==TRUE && quali[2]==TRUE){
@@ -638,7 +653,8 @@ FAT2DBC=function(f1,
           if(mcomp=="sk"){"Scott-Knott"}else{
             if(mcomp=="lsd"){"LSD-Fischer"}else{
               if(mcomp=="duncan"){"Duncan"}}}}
-        cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
+        if(print.on==TRUE){
+          cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))}
 
         if (mcomp == "tukey"){
           for (i in 1:nv2) {
@@ -647,11 +663,11 @@ FAT2DBC=function(f1,
             tukey=TUKEY(respi,trati, a$Df[5], a$`Mean Sq`[5], alpha.t)
             if(transf !=1){tukey$groups$respo=tapply(response[Fator2 == lf2[i]],trati,
                                                      mean, na.rm=TRUE)[rownames(tukey$groups)]}
-            cat("\n----------------------\n")
-
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
-            print(tukey$groups)
+            print(tukey$groups)}
             }
         }
         if (mcomp == "lsd"){
@@ -662,11 +678,12 @@ FAT2DBC=function(f1,
             if(transf !=1){lsd$groups$respo=tapply(response[Fator2 == lf2[i]],trati,
                                                      mean, na.rm=TRUE)[
                                                        rownames(lsd$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
             print(lsd$groups)
-          }
+          }}
         }
 
         if (mcomp == "duncan"){
@@ -676,12 +693,13 @@ FAT2DBC=function(f1,
             duncan=duncan(respi,trati, a$Df[5], a$`Mean Sq`[5], alpha.t)
             if(transf !=1){duncan$groups$respo=tapply(response[Fator2 == lf2[i]],trati,
                                                       mean, na.rm=TRUE)[rownames(duncan$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
 
             print(duncan$groups)
-            }}
+            }}}
         if (mcomp == "sk"){
           for (i in 1:nv2) {
             trati=fatores[, 1][Fator2 == lf2[i]]
@@ -698,11 +716,12 @@ FAT2DBC=function(f1,
             # sk=sk(respi,trati,a$Df[5], a$`Sum Sq`[5],alpha.t)
             if(transf !="1"){sk$respo=tapply(response[Fator2 == lf2[i]],
                                              trati,mean, na.rm=TRUE)[rownames(sk$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
             print(sk)
-          }}
+          }}}
       }
       if(quali[2]==FALSE){
         Fator2a=fator2a#as.numeric(as.character(Fator2))
@@ -710,8 +729,8 @@ FAT2DBC=function(f1,
                             response,
                             Fator1,
                             grau = grau21,
-                            ylab=ylab,
-                            xlab=xlab,
+                            ylab=parse(text=ylab),
+                            xlab=parse(text=lab.factor[2]),
                             theme=theme,
                             point=point,
                             posi=posi,
@@ -720,9 +739,14 @@ FAT2DBC=function(f1,
                             family=family,
                             SSq=ab$`Sum Sq`[5],
                             DFres = ab$Df[5],
-                            legend.title=legend)
+                            legend.title=parse(text=lab.factor[1]),
+                            print.on = print.on,
+                            plot.on = FALSE)
+        if(print.on==TRUE){
+          print(grafico$plot)}
+
         if(quali[1]==FALSE & quali[2]==FALSE){
-          graf=list(grafico,NA)}
+          graf=list(grafico$plot,NA)}
 
                 }
       if(quali[1]==FALSE){
@@ -732,12 +756,13 @@ FAT2DBC=function(f1,
             respi=resp[Fator1 == lf1[i]]
             tukey=TUKEY(respi,trati,a$Df[5],a$`Mean Sq`[5],alpha.t)
             if(transf !=1){tukey$groups$respo=tapply(response[Fator1 == lf1[i]],trati,mean, na.rm=TRUE)[rownames(tukey$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F2 within level",lf1[i],"of F1")
             cat("\n----------------------\n")
 
             print(tukey$groups)
-          }}
+          }}}
         if (mcomp == "lsd"){
           for (i in 1:nv1) {
             trati=fatores[, 2][Fator1 == lf1[i]]
@@ -745,12 +770,13 @@ FAT2DBC=function(f1,
             lsd=LSD(respi,trati,a$Df[5],a$`Mean Sq`[5],alpha.t)
             if(transf !=1){tukey$groups$respo=tapply(response[Fator1 == lf1[i]],
                                                      trati,mean, na.rm=TRUE)[rownames(lsd$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F2 within level",lf1[i],"of F1")
             cat("\n----------------------\n")
 
             print(lsd$groups)
-          }}
+          }}}
 
         if (mcomp == "duncan"){
           for (i in 1:nv1) {
@@ -758,12 +784,13 @@ FAT2DBC=function(f1,
             respi=resp[Fator1 == lf1[i]]
             duncan=duncan(respi,trati,a$Df[5],a$`Mean Sq`[5],alpha.t)
             if(transf !=1){duncan$groups$respo=tapply(response[Fator1 == lf1[i]],trati,mean)[rownames(duncan$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F2 within level",lf1[i],"of F1")
             cat("\n----------------------\n")
 
             print(duncan$groups)
-            }}
+            }}}
         if (mcomp == "sk"){
           for (i in 1:nv1) {
             trati=fatores[, 2][Fator1 == lf1[i]]
@@ -780,11 +807,12 @@ FAT2DBC=function(f1,
             # sk=sk(respi,trati,a$Df[5], a$`Sum Sq`[5],alpha.t)
             if(transf !=1){sk$respo=tapply(response[Fator1 == lf1[i]],trati,
                                            mean, na.rm=TRUE)[rownames(sk)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F2 within level",lf1[i],"of F1")
             cat("\n----------------------\n")
             print(sk)
-          }
+          }}
         }
       }
       if(quali[1]==FALSE){
@@ -793,8 +821,8 @@ FAT2DBC=function(f1,
                             response,
                             Fator2,
                             grau = grau12,
-                            ylab=ylab,
-                            xlab=xlab,
+                            ylab=parse(text=ylab),
+                            xlab=parse(text=lab.factor[1]),
                             theme=theme,
                             posi=posi,
                             point=point,
@@ -803,9 +831,14 @@ FAT2DBC=function(f1,
                             ylim=ylim,
                             SSq=ab$`Sum Sq`[5],
                             DFres = ab$Df[5],
-                            legend.title=legend)
+                            legend.title=parse(text=lab.factor[2]),
+                            print.on = print.on,
+                            plot.on = FALSE)
+        if(plot.on==TRUE){
+          print(grafico$plot)}
+
         if(quali[1]==FALSE & quali[2]==FALSE){
-          graf[[2]]=grafico
+          graf[[2]]=grafico$plot
           grafico=graf}
 
       }
@@ -816,7 +849,8 @@ FAT2DBC=function(f1,
           if(mcomp=="sk"){"Scott-Knott"}else{
             if(mcomp=="lsd"){"LSD-Fischer"}else{
               if(mcomp=="duncan"){"Duncan"}}}}
-        cat(green(italic(paste("Multiple Comparison Test:",teste))))
+        if(print.on==TRUE){
+          cat(green(italic(paste("Multiple Comparison Test:",teste))))}
 
         if (mcomp == "tukey"){
           for (i in 1:nv2) {
@@ -825,11 +859,12 @@ FAT2DBC=function(f1,
             tukey=TUKEY(respi,trati, a$Df[5], a$`Mean Sq`[5], alpha.t)
             if(transf !=1){tukey$groups$respo=tapply(response[Fator2 == lf2[i]],trati,
                                                      mean, na.rm=TRUE)[rownames(tukey$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
             print(tukey$groups)
-          }
+          }}
         }
         if (mcomp == "lsd"){
           for (i in 1:nv2) {
@@ -838,11 +873,12 @@ FAT2DBC=function(f1,
             lsd=LSD(respi,trati, a$Df[5], a$`Mean Sq`[5], alpha.t)
             if(transf !=1){lsd$groups$respo=tapply(response[Fator2 == lf2[i]],trati,
                                                      mean, na.rm=TRUE)[rownames(lsd$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
             print(lsd$groups)
-          }
+          }}
         }
 
         if (mcomp == "duncan"){
@@ -852,12 +888,13 @@ FAT2DBC=function(f1,
             duncan=duncan(respi,trati, a$Df[5], a$`Mean Sq`[5], alpha.t)
             if(transf !=1){duncan$groups$respo=tapply(response[Fator2 == lf2[i]],trati,
                                                       mean, na.rm=TRUE)[rownames(duncan$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
 
             print(duncan$groups)
-          }}
+          }}}
         if (mcomp == "sk"){
           for (i in 1:nv2) {
             trati=fatores[, 1][Fator2 == lf2[i]]
@@ -874,11 +911,12 @@ FAT2DBC=function(f1,
             # sk=sk(respi,trati,a$Df[5], a$`Sum Sq`[5],alpha.t)
             if(transf !="1"){sk$respo=tapply(response[Fator2 == lf2[i]],
                                              trati,mean, na.rm=TRUE)[rownames(sk$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F1 within level",lf2[i],"of F2")
             cat("\n----------------------\n")
             print(sk)
-          }}
+          }}}
       }
       if(quali[2]==FALSE){
         Fator2a=fator2a#as.numeric(as.character(Fator2))
@@ -886,8 +924,8 @@ FAT2DBC=function(f1,
                                   response,
                                   Fator1,
                                   grau = grau21,
-                                  ylab=ylab,
-                                  xlab=xlab,
+                                  ylab=parse(text=ylab),
+                                  xlab=parse(text=lab.factor[2]),
                                   theme=theme,
                                   point=point,
                                   posi=posi,
@@ -896,9 +934,14 @@ FAT2DBC=function(f1,
                                   family=family,
                                   SSq=ab$`Sum Sq`[5],
                                   DFres = ab$Df[5],
-                                  legend.title=legend)
+                                  legend.title=parse(text=lab.factor[1]),
+                                  print.on = print.on,
+                                  plot.on = FALSE)
+        if(plot.on==TRUE){
+          print(grafico$plot)}
+
         if(quali[1]==FALSE & quali[2]==FALSE){
-          graf=list(grafico,NA)}
+          graf=list(grafico$plot,NA)}
 
         }
       if(quali[1]==FALSE){
@@ -908,12 +951,13 @@ FAT2DBC=function(f1,
             respi=resp[Fator1 == lf1[i]]
             tukey=TUKEY(respi,trati,a$Df[5],a$`Mean Sq`[5],alpha.t)
             if(transf !=1){tukey$groups$respo=tapply(response[Fator1 == lf1[i]],trati,mean, na.rm=TRUE)[rownames(tukey$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F2 within level",lf1[i],"of F1")
             cat("\n----------------------\n")
 
             print(tukey$groups)
-          }}
+          }}}
         if (mcomp == "lsd"){
           for (i in 1:nv1) {
             trati=fatores[, 2][Fator1 == lf1[i]]
@@ -921,12 +965,13 @@ FAT2DBC=function(f1,
             lsd=LSD(respi,trati,a$Df[5],a$`Mean Sq`[5],alpha.t)
             if(transf !=1){lsd$groups$respo=tapply(response[Fator1 == lf1[i]],
                                                      trati,mean, na.rm=TRUE)[rownames(lsd$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F2 within level",lf1[i],"of F1")
             cat("\n----------------------\n")
 
             print(lsd$groups)
-          }}
+          }}}
 
         if (mcomp == "duncan"){
           for (i in 1:nv1) {
@@ -934,12 +979,13 @@ FAT2DBC=function(f1,
             respi=resp[Fator1 == lf1[i]]
             duncan=duncan(respi,trati,a$Df[5],a$`Mean Sq`[5],alpha.t)
             if(transf !=1){duncan$groups$respo=tapply(response[Fator1 == lf1[i]],trati,mean)[rownames(duncan$groups)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F2 within level",lf1[i],"of F1")
             cat("\n----------------------\n")
 
             print(duncan$groups)
-          }}
+          }}}
         if (mcomp == "sk"){
           for (i in 1:nv1) {
             trati=fatores[, 2][Fator1 == lf1[i]]
@@ -956,11 +1002,12 @@ FAT2DBC=function(f1,
             # sk=sk(respi,trati,a$Df[5], a$`Sum Sq`[5],alpha.t)
             if(transf !=1){sk$respo=tapply(response[Fator1 == lf1[i]],trati,
                                            mean, na.rm=TRUE)[rownames(sk)]}
-            cat("\n----------------------\n")
+            if(print.on==TRUE){
+              cat("\n----------------------\n")
             cat("Multiple comparison of F2 within level",lf1[i],"of F1")
             cat("\n----------------------\n")
             print(sk)
-          }
+          }}
           }
         }
       if(quali[1]==FALSE){
@@ -970,8 +1017,8 @@ FAT2DBC=function(f1,
                                   Fator2,
                                   grau = grau12,
                                   color=color,
-                                  ylab=ylab,
-                                  xlab=xlab,
+                                  ylab=parse(text=ylab),
+                                  xlab=parse(text=lab.factor[1]),
                                   theme=theme,
                                   point=point,
                                   posi=posi,
@@ -980,9 +1027,13 @@ FAT2DBC=function(f1,
                                   family=family,
                                   SSq=ab$`Sum Sq`[5],
                                   DFres = ab$Df[5],
-                                  legend.title=legend)
+                                  legend.title=parse(text=lab.factor[2]),
+                                  print.on = print.on,
+                                  plot.on = FALSE)
+        if(plot.on==TRUE){print(grafico$plot)}
+
         if(quali[1]==FALSE & quali[2]==FALSE){
-          graf[[2]]=grafico
+          graf[[2]]=grafico$plot
           grafico=graf}
 
       }
@@ -1021,7 +1072,7 @@ FAT2DBC=function(f1,
                              y=media,
                              fill=f2))+
       geom_col(position = "dodge",color="black",width = width.column)+
-      ylab(ylab)+xlab(xlab)+ylim(ylim)+
+      ylab(parse(text=ylab))+xlab(parse(text=lab.factor[1]))+ylim(ylim)+
       theme
       if(errorbar==TRUE){colint=colint+
         geom_errorbar(data=graph,
@@ -1047,22 +1098,40 @@ FAT2DBC=function(f1,
                                                   round(abs(sqrt(a$`Mean Sq`[5])/mean(resp))*100,2),"%"))}
     if(angle !=0){colint=colint+theme(axis.text.x=element_text(hjust = 1.01,angle = angle))}
     if(color=="gray"){colint=colint+scale_fill_grey()}
-    print(colint)
+    if(length(fill)>=2){colint=colint+scale_fill_manual(values=fill)}
+    if(plot.on==TRUE){
+      print(colint)}
     grafico=colint
     letras=paste(graph$letra,graph$letra1,sep="")
     matriz=data.frame(t(matrix(paste(format(graph$media,digits = dec),letras),ncol = length(levels(Fator1)))))
     rownames(matriz)=levels(Fator1)
     colnames(matriz)=levels(Fator2)
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    if(print.on==TRUE){
+      cat(green(bold("\n-----------------------------------------------------------------\n")))
     cat(green(bold("Final table")))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     print(matriz)
-
-    message(black("\n\nAverages followed by the same lowercase letter in the column \nand uppercase in the row do not differ by the",mcomp,"(p<",alpha.t,")"))
+    message(black("\n\nAverages followed by the same lowercase letter in the column \nand uppercase in the row do not differ by the",mcomp,"(p<",alpha.t,")"))}
     }
   }
   if(a$`Pr(>F)`[4]>alpha.f){
     names(graficos)=c("residplot","graph1","graph2")
-    graficos}else{colints=list(residplot,grafico)}
+    colints=graficos}else{
+      colints=list(residplot=residplot,interaction=grafico)}
+  output=list(plot=if(any(a$`Pr(>F)`[c(1,2,4)] < alpha.f)){colints}else{NA},
+              dec=dec,
+              family=family,
+              ylab=ylab,
+              textsize=textsize,
+              sup=sup,
+              anova=anava,
+              resp=resp,
+              transf=transf,
+              f1=f1,
+              f2=f2,
+              norm=norm1,
+              homog=homog1,
+              indep=indep,
+              alpha.f=alpha.f)
 }
 
