@@ -1,6 +1,6 @@
 #' Analysis: DIC experiment in double factorial design with an additional treatment
 #' @description Analysis of an experiment conducted in a completely randomized design in a double factorial scheme using analysis of variance of fixed effects.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param f1 Numeric or complex vector with factor 1 levels
@@ -12,7 +12,7 @@
 #' @param homog Homogeneity test of variances (\emph{default} is Bartlett)
 #' @param mcomp Multiple comparison test (Tukey (\emph{default}), LSD and Duncan)
 #' @param quali Defines whether the factor is quantitative or qualitative (\emph{qualitative})
-#' @param names.fat Name of factors
+#' @param names.fat Name of factors (this argument uses the \emph{parse} function)
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
 #' @param grau Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with two elements.
@@ -22,10 +22,7 @@
 #' @param constant Add a constant for transformation (enter value)
 #' @param geom Graph type (columns or segments (For simple effect only))
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
-#' @param xlab.factor Provide a vector with two observations referring to the x-axis name of factors 1 and 2, respectively, when there is an isolated effect of the factors. This argument uses `parse`.
-#' @param legend Legend title name
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
 #' @param ad.label Aditional label
 #' @param fill Defines chart color (to generate different colors for different treatments, define fill = "trat")
 #' @param angle x-axis scale text rotation
@@ -44,6 +41,8 @@
 #' @param ylim y-axis scale
 #' @param point This function defines whether the point must have all points ("all"), mean ("mean"), standard deviation (\emph{default} - "mean_sd") or mean with standard error ("mean_se") if quali= FALSE. For quali=TRUE, `mean_sd` and `mean_se` change which information will be displayed in the error bar.
 #' @param angle.label label angle
+#' @param print.on Print output
+#' @param plot.on Plot output
 #' @import ggplot2
 #' @importFrom crayon green
 #' @importFrom crayon bold
@@ -80,8 +79,10 @@
 #' library(AgroR)
 #' data(cloro)
 #' respAd=c(268, 322, 275, 350, 320)
-#' with(cloro, FAT2DIC.ad(f1, f2, bloco, resp, respAd, ylab="Number of nodules", legend = "Stages"))
+#' with(cloro, FAT2DIC.ad(f1, f2, bloco, resp, respAd, ylab="Number of nodules"))
 #'
+
+
 FAT2DIC.ad=function(f1,
                     f2,
                     repe,
@@ -102,9 +103,6 @@ FAT2DIC.ad=function(f1,
                     geom="bar",
                     theme=theme_classic(),
                     ylab="Response",
-                    xlab="",
-                    xlab.factor=c("F1","F2"),
-                    legend="Legend",
                     ad.label="Additional",
                     color="rainbow",
                     fill="lightblue",
@@ -122,7 +120,11 @@ FAT2DIC.ad=function(f1,
                     point="mean_sd",
                     sup=NA,
                     ylim=NA,
-                    angle.label=0){
+                    angle.label=0,
+                    print.on=TRUE,
+                    plot.on=TRUE){
+  lab.factor=c(gsub(" ","~",names.fat[1]),gsub(" ","~",names.fat[2]))
+  ylab=parse(text=gsub(" ","~",ylab))
   if(angle.label==0){hjust=0.5}else{hjust=0}
   requireNamespace("crayon")
   requireNamespace("ggplot2")
@@ -236,17 +238,19 @@ FAT2DIC.ad=function(f1,
     scale_x_continuous(breaks=1:length(respad))+
     theme_classic()+theme(axis.text.y = element_text(size=textsize),
                           axis.text.x = element_blank())+
-    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",size=1)
+    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",linewidth=1)
   # print(residplot)
 
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  if(print.on==TRUE){
+    cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Normality of errors")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   normal=data.frame(Method=paste(norm1$method,"(",names(norm1$statistic),")",sep=""),
                     Statistic=norm1$statistic,
                     "p-value"=norm1$p.value)
   rownames(normal)=""
-  print(normal)
+  if(print.on==TRUE){
+    print(normal)
   cat("\n")
 
   message(if(norm1$p.value>0.05){
@@ -254,12 +258,13 @@ FAT2DIC.ad=function(f1,
     else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, errors do not follow a normal distribution"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Homogeneity of Variances")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   homoge=data.frame(Method=method,
                     Statistic=statistic,
                     "p-value"=phomog)
   rownames(homoge)=""
-  print(homoge)
+  if(print.on==TRUE){
+    print(homoge)
   cat("\n")
 
   message(if(homog1$p.value[1]>0.05){
@@ -267,13 +272,14 @@ FAT2DIC.ad=function(f1,
     else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, the variances are not homogeneous"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Independence from errors")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   indepe=data.frame(Method=paste(indep$method,"(",
                                  names(indep$statistic),")",sep=""),
                     Statistic=indep$statistic,
                     "p-value"=indep$p.value)
   rownames(indepe)=""
-  print(indepe)
+  if(print.on==TRUE){
+    print(indepe)
   cat("\n")
 
   message(if(indep$p.value>0.05){
@@ -291,32 +297,35 @@ FAT2DIC.ad=function(f1,
   cat("\n")
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Analysis of Variance")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   anava1=as.matrix(data.frame(anava))
   colnames(anava1)=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
   rownames(anava1)=c(names.fat[1],names.fat[2],
                      paste(names.fat[1],"\u00D7",names.fat[2]),"Ad \u00D7 Factorial","Residuals")
-  print(anava1,na.print = "")
+  if(print.on==TRUE){
+    print(anava1,na.print = "")
   cat("\n")
   if(anava$`Pr(>F)`[4]<alpha.f){"The additional treatment does differ from the factorial by the F test"}else{"The additional treatment does not differ from the factorial by the F test "}
   if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 &&homog1$p.value<0.05){
     message("\nYour analysis is not valid, suggests using a non-parametric test and try to transform the data\n")}else{}
   if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){
     message("\nYour analysis is not valid, suggests using the function FATDIC.art\n")}else{}
-  message(if(transf !=1){blue("NOTE: resp = transformed means; respO = averages without transforming\n")})
+  message(if(transf !=1){blue("NOTE: resp = transformed means; respO = averages without transforming\n")})}
 
   if (anava$`Pr(>F)`[3] > alpha.f)
-  { cat(green(bold("-----------------------------------------------------------------\n")))
+  { if(print.on==TRUE){
+    cat(green(bold("-----------------------------------------------------------------\n")))
     cat(green(bold("No significant interaction")))
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     fatores <- data.frame(Fator1 = factor(fator1), Fator2 = factor(fator2))
     fatoresa <- data.frame(Fator1 = fator1a, Fator2 = fator2a)
     graficos=list(1,2,3)
 
     for (i in 1:2) {if (anava$`Pr(>F)`[i] <= alpha.f)
-    {cat(green(bold("\n-----------------------------------------------------------------\n")))
-      cat(bold(names.fat[i]))
+    {if(print.on==TRUE){
       cat(green(bold("\n-----------------------------------------------------------------\n")))
+      cat(bold(names.fat[i]))
+      cat(green(bold("\n-----------------------------------------------------------------\n")))}
       if(quali[i]==TRUE){
         ## Tukey
         if(mcomp=="tukey"){
@@ -345,8 +354,9 @@ FAT2DIC.ad=function(f1,
           if(mcomp=="sk"){"Scott-Knott"}else{
             if(mcomp=="lsd"){"LSD-Fischer"}else{
               if(mcomp=="duncan"){"Duncan"}}}}
-        cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
-        print(letra1)
+        if(print.on==TRUE){
+          cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
+        print(letra1)}
         ordem=unique(as.vector(unlist(fatores[i])))
         #=====================================================
         if(point=="mean_sd"){desvio=tapply(response, c(fatores[i]), sd, na.rm=TRUE)[ordem]}
@@ -374,7 +384,7 @@ FAT2DIC.ad=function(f1,
         else{grafico=grafico+
           geom_col(aes(fill=trats),
                    fill=fill,color=1,width = width.column)}
-        grafico=grafico+theme+ylab(ylab)+xlab(parse(text = xlab.factor[i]))+ylim(ylim)
+        grafico=grafico+theme+ylab(parse(text=ylab))+xlab(parse(text = lab.factor[i]))+ylim(ylim)
         if(errorbar==TRUE){grafico=grafico+
           geom_text(aes(y=media+
                           sup+if(sup<0){-desvio}else{desvio},
@@ -400,7 +410,7 @@ FAT2DIC.ad=function(f1,
           geom_point(aes(color=trats),size=5)}
         else{grafico=grafico+
           geom_point(aes(color=trats),fill="gray",pch=21,color="black",size=5)}
-        grafico=grafico+theme+ylab(ylab)+xlab(parse(text = xlab.factor[i]))+ylim(ylim)
+        grafico=grafico+theme+ylab(parse(text=ylab))+xlab(parse(text = lab.factor[i]))+ylim(ylim)
         if(errorbar==TRUE){grafico=grafico+
           geom_text(aes(y=media+sup+
                           if(sup<0){-desvio}else{desvio},
@@ -425,34 +435,36 @@ FAT2DIC.ad=function(f1,
                                                         else{paste("=", round(anava$`Pr(>F)`[i],4))},"; CV = ",
                                                         round(abs(sqrt(anava$`Mean Sq`[5])/mean(c(resp,respAd),na.rm=TRUE))*100,2),"%"))}
         if(color=="gray"){grafico=grafico+scale_fill_grey()}
-        print(grafico)
-        cat("\n\n")
       }
 
       # Regression
       if(quali[i]==FALSE){
         # dose=as.numeric(as.character(as.vector(unlist(fatores[i]))))
-        dose=as.vector(unlist(fatoresa[i]))
+        dose=as.numeric(as.vector(unlist(fatoresa[i])))
         grafico=polynomial(dose,
                            response,
                            grau = grau[i],
-                           ylab=ylab,
-                           xlab=parse(text = xlab.factor[i]),
+                           ylab=parse(text=ylab),
+                           xlab=parse(text = lab.factor[i]),
                            posi=posi,
                            theme=theme,
                            textsize=textsize,
                            point=point,
-                           family=family,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5])
-        grafico=grafico[[1]]+
+                           family=family,
+                           SSq = anava$`Sum Sq`[5],
+                           DFres = anava$Df[5],print.on = print.on,
+                           plot.on = FALSE)
+        grafico=grafico$plot+
           geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
           scale_color_manual(values = "black")+labs(color="")}
-
+      if(plot.on==TRUE){print(grafico)}
       # Ns
       #if (a$`Pr(>F)`[i] > alpha.f) {cat("\nAccording to the F test, the means do not differ\n")}
       graficos[[i+1]]=grafico}}
     graficos[[1]]=residplot
 
-    if(anava$`Pr(>F)`[1]>=alpha.f && anava$`Pr(>F)`[2] <alpha.f){
+    if(print.on==TRUE){
+      if(anava$`Pr(>F)`[1]>=alpha.f && anava$`Pr(>F)`[2] <alpha.f){
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       cat(green("Isolated factors 1 not significant"))
       cat(green(bold("\n-----------------------------------------------------------------\n")))
@@ -472,13 +484,14 @@ FAT2DIC.ad=function(f1,
       cat(green("Isolated factors not significant"))
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       print(tapply(response,list(fator1,fator2),mean, na.rm=TRUE))}
-  }
+  }}
 
   if (anava$`Pr(>F)`[3]  <= alpha.f) {
     fatores <- data.frame(Fator1, Fator2)
-    cat(green(bold("-----------------------------------------------------------------\n")))
+    if(print.on==TRUE){
+      cat(green(bold("-----------------------------------------------------------------\n")))
     cat(green(bold("Significant interaction: analyzing the interaction")))
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     des1<-aov(resp~Fator2/Fator1)
 
     l1<-vector('list',nv2)
@@ -495,10 +508,11 @@ FAT2DIC.ad=function(f1,
     des1.tab$`F value`=des1.tab$`Mean Sq`/anava$`Mean Sq`[5]
     des1.tab$`Pr(>F)`=1-pf(des1.tab$`F value`,des1.tab$Df,anava$Df[5])
 
-    cat("\n-----------------------------------------------------------------\n")
+    if(print.on==TRUE){
+      cat("\n-----------------------------------------------------------------\n")
     cat("Analyzing ", names.fat[1], " inside of the level of ",names.fat[2])
     cat("\n-----------------------------------------------------------------\n")
-    cat("\n")
+    cat("\n")}
     rn<-numeric(0)
     for (j in 1:nv2) {
       rn <- c(rn, paste(paste(names.fat[1], ":", names.fat[2],
@@ -507,7 +521,8 @@ FAT2DIC.ad=function(f1,
     rownames(des1.tab)=c(names.fat[2],
                          paste(names.fat[1],"\u00D7",names.fat[2],"+",names.fat[1]),
                          paste("  ",rn))
-    print(des1.tab)
+    if(print.on==TRUE){
+      print(des1.tab)}
     desdobramento1=des1.tab
     if(quali[1]==TRUE & quali[2]==TRUE){
       if (mcomp == "tukey"){
@@ -587,10 +602,11 @@ FAT2DIC.ad=function(f1,
         letra=datag$letra}
     }
 
-    cat("\n-----------------------------------------------------------------\n")
+    if(print.on==TRUE){
+      cat("\n-----------------------------------------------------------------\n")
     cat("Analyzing ", names.fat[2], " inside of the level of ",names.fat[1])
     cat("\n-----------------------------------------------------------------\n")
-    cat("\n")
+    cat("\n")}
     des1<-aov(resp~Fator1/Fator2)
 
     l1<-vector('list',nv1)
@@ -615,7 +631,8 @@ FAT2DIC.ad=function(f1,
     rownames(des1.tab)=c(names.fat[1],
                          paste(names.fat[1],"\u00D7",names.fat[2],"+",names.fat[2]),
                          paste("  ",rn))
-    print(des1.tab)
+    if(print.on==TRUE){
+      print(des1.tab)}
     desdobramento2=des1.tab
 
     if(quali[1]==TRUE & quali[2]==TRUE){
@@ -674,73 +691,86 @@ FAT2DIC.ad=function(f1,
 
     if(quali[1]==FALSE && color=="gray"| quali[2]==FALSE && color=="gray"){
       if(quali[2]==FALSE){
-        Fator2=fator2a
+        Fator2=as.numeric(as.character(fator2a))
         grafico=polynomial2(Fator2,response,Fator1,
                             grau = grau21,
-                            ylab=ylab,
-                            xlab=xlab,
+                            ylab=parse(text=ylab),
+                            xlab=parse(text=lab.factor[2]),
                             theme=theme,
                             posi=posi,
                             point=point,
                             textsize=textsize,
                             family=family,
                             ylim=ylim,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5],
-                            legend.title=legend)+
-          geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
-          scale_color_manual(values = "black")+labs(color="")}
+                            legend.title=parse(text=lab.factor[1]),
+                            print.on = print.on,
+                            plot.on = FALSE)$plot+
+          geom_hline(aes(lty=ad.label,yintercept=mean(responseAd,na.rm=TRUE)))+scale_linetype_manual(values=2)+labs(lty="")
+        if(plot.on==TRUE){print(grafico)}
+      }
       if(quali[2]==TRUE){
-        Fator1=fator1a
+        Fator1=as.numeric(as.character(fator1a))
         grafico=polynomial2(Fator1,
                             response,
                             Fator2,
                             grau = grau12,
-                            ylab=ylab,
-                            xlab=xlab,
+                            ylab=parse(text=ylab),
+                            xlab=parse(text=lab.factor[1]),
                             theme=theme,
                             posi=posi,
                             point=point,
                             textsize=textsize,
                             family=family,
                             ylim=ylim,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5],
-                            legend.title=legend)+
-          geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
-          scale_color_manual(values = "black")+labs(color="")}
+                            legend.title=parse(text=lab.factor[2]),
+                            print.on = print.on,
+                            plot.on = FALSE)$plot+
+          geom_hline(aes(lty=ad.label,yintercept=mean(responseAd,na.rm=TRUE)))+scale_linetype_manual(values=2)+labs(lty="")
+        if(plot.on==TRUE){print(grafico)}
+      }
     }
     if(quali[1]==FALSE && color=="rainbow"| quali[2]==FALSE && color=="rainbow"){
       if(quali[2]==FALSE){
-        Fator2=fator2a
+        Fator2=as.numeric(as.character(fator2a))
         grafico=polynomial2_color(Fator2,
                                   response,
                                   Fator1,
                                   grau = grau21,
-                                  ylab=ylab,
-                                  xlab=xlab,
+                                  ylab=parse(text=ylab),
+                                  xlab=parse(text=lab.factor[2]),
                                   theme=theme,
                                   posi=posi,
                                   point=point,
                                   textsize=textsize,
                                   family=family,
-                                  ylim=ylim,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5],
-                                  legend.title=legend)+
-          geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
-          scale_color_manual(values = "black")+labs(color="")}
+                                  ylim=ylim,SSq = anava$`Sum Sq`[5],
+                                  DFres = anava$Df[5],
+                                  legend.title=parse(text=lab.factor[1]),
+                                  print.on = print.on,
+                                  plot.on = FALSE)$plot+
+          geom_hline(aes(lty=ad.label,yintercept=mean(responseAd,na.rm=TRUE)))+scale_linetype_manual(values=2)+labs(lty="")
+        if(plot.on==TRUE){print(grafico)}
+      }
       if(quali[2]==TRUE){
-        Fator1=fator1a
+        Fator1=as.numeric(as.character(fator1a))
         grafico=polynomial2_color(Fator1,
                                   response,
                                   Fator2,
                                   grau = grau12,
-                                  ylab=ylab,
-                                  xlab=xlab,
+                                  ylab=parse(text=ylab),
+                                  xlab=parse(text=lab.factor[1]),
                                   theme=theme,
                                   posi=posi,
                                   point=point,
                                   textsize=textsize,
                                   family=family,
                                   ylim=ylim,SSq = anava$`Sum Sq`[5],DFres = anava$Df[5],
-                                  legend.title=legend)+
-          geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
-          scale_color_manual(values = "black")+labs(color="")}
+                                  legend.title=parse(text=lab.factor[2]),
+                                  print.on = print.on,
+                                  plot.on = FALSE)$plot+
+          geom_hline(aes(lty=ad.label,yintercept=mean(responseAd,na.rm=TRUE)))+scale_linetype_manual(values=2)+labs(lty="")
+        if(plot.on==TRUE){print(grafico)}
+      }
     }
     if(quali[1] & quali[2]==TRUE){
       media=tapply(response,list(Fator1,Fator2), mean, na.rm=TRUE)
@@ -778,7 +808,7 @@ FAT2DIC.ad=function(f1,
                         y=media,
                         fill=f2))+
         geom_col(position = "dodge",color="black",width = width.column)+
-        ylab(ylab)+xlab(xlab)+ylim(ylim)+
+        ylab(parse(text=ylab))+xlab(parse(text = lab.factor[1]))+ylim(ylim)+
         theme
       if(errorbar==TRUE){colint=colint+
         geom_errorbar(data=graph,
@@ -800,7 +830,7 @@ FAT2DIC.ad=function(f1,
                           axis.title = element_text(size=textsize,color="black",family = family),
                           legend.text = element_text(family = family,size=textsize),
                           legend.title = element_text(family = family,size=textsize),
-                          legend.position = posi)+labs(fill=legend)+
+                          legend.position = posi)+labs(fill=parse(text=lab.factor[2]))+
         geom_hline(aes(color=ad.label,yintercept=mean(responseAd,na.rm=TRUE)),lty=2)+
         scale_color_manual(values = "black")+labs(color="")
       if(CV==TRUE){colint=colint+labs(caption=paste("p-value ", if(anava$`Pr(>F)`[3]<0.0001){paste("<", 0.0001)}
@@ -809,7 +839,8 @@ FAT2DIC.ad=function(f1,
       if(angle !=0){colint=colint+
         theme(axis.text.x=element_text(hjust = 1.01,angle = angle))}
       if(color=="gray"){colint=colint+scale_fill_grey()}
-      print(colint)
+      if(plot.on==TRUE){
+        print(colint)}
       grafico=colint
       letras=paste(graph$letra,
                    graph$letra1,
@@ -817,14 +848,40 @@ FAT2DIC.ad=function(f1,
       matriz=data.frame(t(matrix(paste(format(graph$media,digits = dec),letras),ncol = length(levels(Fator1)))))
       rownames(matriz)=levels(Fator1)
       colnames(matriz)=levels(Fator2)
-      cat(green(bold("\n-----------------------------------------------------------------\n")))
+      if(print.on==TRUE){
+        cat(green(bold("\n-----------------------------------------------------------------\n")))
       cat(green(bold("Final table")))
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       print(matriz)
-      message(black("\n\nAverages followed by the same lowercase letter in the column and \nuppercase in the row do not differ by the",mcomp,"(p<",alpha.t,")"))
+      message(black("\n\nAverages followed by the same lowercase letter in the column and \nuppercase in the row do not differ by the",mcomp,"(p<",alpha.t,")"))}
     }
   }
   if(anava$`Pr(>F)`[3]>alpha.f){
     names(graficos)=c("residplot","graph1","graph2")
-    graficos}else{colints=list("residplot"=residplot,"grafico"=grafico)}
+    colints=graficos}else{colints=list("residplot"=residplot,"interaction"=grafico)}
+  output=list(plot=if(any(anava$`Pr(>F)`[1:3] < alpha.f)){colints}else{NA},
+              dec=dec,
+              family=family,
+              ylab=parse(text=ylab),
+              textsize=textsize,
+              sup=sup,
+              ordempadronizado=ordempadronizado,
+              posi=posi,
+              anova=anava,
+              resp=resp,
+              transf=transf,
+              f1=f1,
+              f2=f2,
+              norm=norm1,
+              homog=homog1,
+              indep=indep,
+              alpha.f=alpha.f,
+              alpha.t=alpha.t,
+              grau12=grau12,
+              grau21=grau21,
+              xlab.factor=lab.factor,
+              point=point,
+              ylab=ylab,
+              respAd=respAd)
+
 }
