@@ -87,7 +87,7 @@ PSUBFAT2DBC=function(f1,
     scale_x_continuous(breaks=1:length(resids))+
     theme_classic()+theme(axis.text.y = element_text(size=12),
                           axis.text.x = element_blank())+
-    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",size=1)
+    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",linewidth=1)
 
 
   cat(green(bold("\n-----------------------------------------------------------------\n")))
