@@ -61,9 +61,8 @@ mean_stat <-
     rownames(junto)<-1:(nrow(junto))
     return(junto)}
 
-levenehomog <- function (y, ...) {
-  UseMethod("levenehomog")}
-
+#' @noRd
+#' @method levenehomog default
 levenehomog.default <- function (y, group, center=median, ...) {
   if (!is.numeric(y))
     stop(deparse(substitute(y)), " is not a numeric variable")
@@ -80,7 +79,8 @@ levenehomog.default <- function (y, group, center=median, ...) {
                                   if(!(dots == "NULL")) paste(":", dots),  ")", sep="")
   table}
 
-
+#' @noRd
+#' @method levenehomog formula
 levenehomog.formula <- function(y, data, ...) {
   form <- y
   mf <- if (missing(data)) model.frame(form) else model.frame(form, data)
@@ -93,6 +93,8 @@ levenehomog.formula <- function(y, data, ...) {
     group <- interaction(mf[,2:dim(mf)[2]])}
   levenehomog.default(y=y, group=group, ...)}
 
+#' @noRd
+#' @method levenehomog lm
 levenehomog.lm <- function(y, ...) {
   m <- model.frame(y)
   m$..y <- model.response(m)
@@ -100,6 +102,10 @@ levenehomog.lm <- function(y, ...) {
   f[2] <- expression(..y)
   levenehomog.formula(f, data=m, ...)}
 
+#' @noRd
+levenehomog <- function (y, ...) {
+  UseMethod("levenehomog")}
+
 ordenacao=function (treatment, means, alpha, pvalue, console){
     n <- length(means)
     z <- data.frame(treatment, means)
@@ -215,8 +221,8 @@ duncan <- function(y,
       if(x=="NaN")break
       else Tprob[k]<-x
     }
-    if(k<(ntr-1)){
-      for(i in k:(ntr-1)){
+    if((k-1)<(ntr-1)){
+      for(i in (k-1):(ntr-1)){
         f <- Vectorize(function(x)ptukey(x,i+1,DFerror)-(1-alpha)^i)
         Tprob[i]<-uniroot(f, c(0,100))$root
       }
@@ -730,7 +736,20 @@ scottknott=function(means, df1, QME, nrep, alpha=0.05){
     v8=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]])}
     v9=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]])}
     v10=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]])}
-    lv=list(v1,v2,v3,v4,v5,v6,v7,v8,v9,v10)
+    v11=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]])}
+    v12=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]])}
+    v13=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]])}
+    v14=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]])}
+    v15=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]])}
+    v16=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]])}
+    v17=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]])}
+    v18=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]])}
+    v19=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]])}
+    v20=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]],u[[20]])}
+    v21=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]],u[[20]],u[[21]])}
+    v22=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]],u[[20]],u[[21]],u[[22]])}
+    v23=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]],u[[20]],u[[21]],u[[22]],u[[23]])}
+    lv=list(v1,v2,v3,v4,v5,v6,v7,v8,v9,v10,v11,v12,v13,v14,v15,v16,v17,v18,v19,v20,v21,v22,v23)
     l=length(u)
     ti=lv[[l]]
     u=ti()
@@ -749,7 +768,20 @@ scottknott=function(means, df1, QME, nrep, alpha=0.05){
   v8=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]])}
   v9=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]])}
   v10=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]])}
-  lv=list(v1,v2,v3,v4,v5,v6,v7,v8,v9,v10)
+  v11=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]])}
+  v12=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]])}
+  v13=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]])}
+  v14=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]])}
+  v15=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]])}
+  v16=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]])}
+  v17=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]])}
+  v18=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]])}
+  v19=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]])}
+  v20=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]],u[[20]])}
+  v21=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]],u[[20]],u[[21]])}
+  v22=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]],u[[20]],u[[21]],u[[22]])}
+  v23=function(...){c(u[[1]],u[[2]],u[[3]],u[[4]],u[[5]],u[[6]],u[[7]],u[[8]],u[[9]],u[[10]],u[[11]],u[[12]],u[[13]],u[[14]],u[[15]],u[[16]],u[[17]],u[[18]],u[[19]],u[[20]],u[[21]],u[[22]],u[[23]])}
+  lv=list(v1,v2,v3,v4,v5,v6,v7,v8,v9,v10,v11,v12,v13,v14,v15,v16,v17,v18,v19,v20,v21,v22,v23)
   l=length(u)
   ti=lv[[l]]
   u=ti()
