@@ -8,7 +8,6 @@
 #' @param facet.size Font size facets
 #' @param ylab Y-axis name
 #' @param width.bar Width error bar
-#' @param width.col Width Column
 #' @param sup Number of units above the standard deviation or average bar on the graph
 #'
 #' @return Returns a column chart grouped by facets
@@ -29,15 +28,13 @@ bargraph_onefactor=function(analysis,
                             facet.size=14,
                             ylab=NULL,
                             width.bar=0.3,
-                            width.col=0.9,
                             sup=NULL){
   requireNamespace("ggplot2")
   results=as.list(1:length(analysis))
   for(i in 1:length(analysis)){
-    if(is.null(labels)==TRUE){analysis[[i]][[1]]$plot$dadosm$facet=rep(i,
-                                                                       e=nrow(analysis[[i]][[1]]$plot$dadosm))}else{
-                                                                         analysis[[i]][[1]]$plot$dadosm$facet=rep(labels[i],e=nrow(analysis[[i]][[1]]$plot$dadosm))}
-    results[[i]]=analysis[[i]][[1]]$plot$dadosm}
+    if(is.null(labels)==TRUE){analysis[[i]]$dadosm$facet=rep(i, e=nrow(analysis[[i]]$dadosm))}else{
+      analysis[[i]]$dadosm$facet=rep(labels[i],e=nrow(analysis[[i]]$dadosm))}
+    results[[i]]=analysis[[i]]$dadosm}
   tabela=do.call("rbind",results)
   if(is.null(sup)==TRUE){sup=0.1*mean(tabela$media)}
   media=tabela$media
@@ -45,13 +42,13 @@ bargraph_onefactor=function(analysis,
   trats=tabela$trats
   letra=tabela$letra
   graph=ggplot(tabela,aes(y=media,x=trats))+
-    geom_col(color="black",fill="lightblue",width = width.col)+
+    geom_col(color="black",fill="lightblue",width = analysis$width.column)+
     facet_grid(~facet,scales = "free", space='free')+
     geom_errorbar(aes(ymin=media-desvio,ymax=media+desvio),width=width.bar)+
     geom_text(aes(y=media+desvio+sup,x=trats,label=letra))+xlab("")+
-    analysis[[1]][[1]]$theme+theme(strip.text = element_text(size=facet.size))
-  if(is.null(ylab)==TRUE){graph=graph+ylab(analysis[[1]][[1]]$plot$ylab)}else{graph=graph+ylab(ylab)}
+    analysis$plot$theme+theme(strip.text = element_text(size=facet.size))
+  if(is.null(ylab)==TRUE){graph=graph+ylab(analysis$plot$labels$y)}else{graph=graph+ylab(parse(text=ylab))}
   if(ocult.facet==TRUE){graph=graph+theme(strip.text = element_blank())}
   if(ocult.box==TRUE){graph=graph+theme(strip.background = element_blank())}
-  list(graph)[[1]]}
+  graph}
 
