@@ -1,7 +1,7 @@
 #' Analysis: Joint analysis of experiments in randomized block design
 #'
 #' @description Function of the AgroR package for joint analysis of experiments conducted in a randomized qualitative or quantitative single-block design with balanced data.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param trat Numerical or complex vector with treatments
@@ -18,8 +18,8 @@
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
 #' @param grau Degree of polynomial in case of quantitative factor (\emph{default} is 1)
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
+#' @param xlab Treatments name (this argument uses the \emph{parse} function)
 #' @param title Graph title
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param dec Number of cells
@@ -140,7 +140,7 @@ conjdbc=function(trat,
                    aes(x=var2,
                        y=var1,
                        fill=resp1))+
-    geom_tile(color="gray50",size=1)+
+    geom_tile(color="gray50",linewidth=1)+
     scale_x_discrete(position = "top")+
     scale_fill_distiller(palette = "RdBu",direction = 1)+
     ylab("Numerator")+
@@ -187,13 +187,13 @@ conjdbc=function(trat,
   if(norm=="sf"){norm1=nortest::sf.test(d$residuals)}
 
   if(homog=="bt"){
-    homog1 = bartlett.test(d$res ~ trat)
+    homog1 = bartlett.test(d$res ~ tratamento)
     statistic=homog1$statistic
     phomog=homog1$p.value
     method=paste("Bartlett test","(",names(statistic),")",sep="")
   }
   if(homog=="levene"){
-    homog1 = levenehomog(d$res~trat)
+    homog1 = levenehomog(d$res~tratamento)
     statistic=homog1$`F value`[1]
     phomog=homog1$`Pr(>F)`[1]
     method="Levene's Test (center = median)(F)"
@@ -221,7 +221,7 @@ conjdbc=function(trat,
   rownames(homoge)=""
   print(homoge)
   cat("\n")
-  cat(if(homog1$p.value>0.05){black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, the variances can be considered homogeneous")}
+  cat(if(homog1$p.value[1]>0.05){black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, the variances can be considered homogeneous")}
       else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, the variances are not homogeneous\n"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Independence from errors")))
@@ -290,14 +290,14 @@ conjdbc=function(trat,
                                                alpha = alpha.t)$groups[unique(as.character(trat)),]
           comp=LSD(aov1,"tratamento")$groups}
           if(mcomp=="sk"){
-            anova=anova(aov1)
+            anova3=anova(aov1)
             data=dados[dados$local==levels(dados$local)[i],]
-            nrep=table(data$trat)[1]
-            medias=sort(tapply(data$resp,data$trat,mean),decreasing = TRUE)
+            nrep=table(data$tratamento)[1]
+            medias=sort(tapply(data$resp,data$tratamento,mean),decreasing = TRUE)
             letra=scottknott(means = medias,
-                             df1 = anova$Df[3],
+                             df1 = anova3$Df[3],
                              nrep = nrep,
-                             QME = anova$`Mean Sq`[3],
+                             QME = anova3$`Mean Sq`[3],
                              alpha = alpha.t)
             letra1=data.frame(resp=medias,groups=letra)[unique(as.character(trat)),]
             tukey[[i]]=letra1
@@ -339,6 +339,7 @@ conjdbc=function(trat,
                   axis.title = element_text(size=textsize,color="black", family = family),
                   axis.text = element_text(size=textsize,color="black", family = family),
                   legend.position = "none")
+          print(grafico)
           graficos[[i]]=grafico}
         print(anova,na.print = "")
         teste=if(mcomp=="tukey"){"Tukey HSD"}else{
@@ -364,6 +365,7 @@ conjdbc=function(trat,
                            theme=theme,
                            posi="top",
                            se=errorbar)[[1]]
+        print(grafico)
         graficos[[i]]=grafico}
       }}
   if(a$`Pr(>F)`[1] < alpha.f && qmresmedio < homog.value){
@@ -453,6 +455,7 @@ conjdbc=function(trat,
                   axis.title = element_text(size=textsize,color="black", family = family),
                   axis.text = element_text(size=textsize,color="black", family = family),
                   legend.position = "none")
+          print(grafico)
           graficos[[i]]=grafico}
       }
       print(anova,na.print = "")
@@ -480,6 +483,7 @@ conjdbc=function(trat,
                            SSq = SQconj,
                            DFres = GLconj,
                            se=errorbar)[[1]]
+        print(grafico)
         graficos[[i]]=grafico}
     }
   }
@@ -558,6 +562,7 @@ conjdbc=function(trat,
 
       cat(green(bold("-----------------------------------------------------------------\n")))
       print(tukeyjuntos)
+      print(grafico1)
       }
     if(quali==FALSE){grafico1=polynomial(tratnum,
                                      response,grau = grau,
@@ -568,13 +573,24 @@ conjdbc=function(trat,
                                      theme=theme,
                                      posi="top",SSq = SQconj,DFres = GLconj,
                                      se=errorbar)
+    print(grafico1)
     }
     graficos=list(grafico1)
   }
   cat(if(transf=="1"){}else{blue("\nNOTE: resp = transformed means; respO = averages without transforming\n")})
 
-  if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test and try to transform the data"))}
-  if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test"))}
+  if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 && homog1$p.value[1]<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test and try to transform the data"))}
+  if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value[1]<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test"))}
   # print(graficos)
-  (graph=as.list(graficos))
+  graph=list(plot=graficos,
+             trat=trat,
+             ylab=ylab,
+             qmresmedio=qmresmedio,
+             datas=datas,
+             homog.value=homog.value,
+             homog=homog1,
+             indep=indep,
+             norm=norm1,
+             alpha.f=alpha.f,
+             dadosm=dadosm)
 }
