@@ -1,7 +1,7 @@
 #' Analysis: Joint analysis of experiments in completely randomized design
 #'
 #' @description Function of the AgroR package for joint analysis of experiments conducted in a completely randomized design with a qualitative or quantitative factor with balanced data.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param trat Numerical or complex vector with treatments
@@ -18,8 +18,8 @@
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
 #' @param grau Degree of polynomial in case of quantitative factor (\emph{default} is 1)
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
+#' @param xlab Treatments name (this argument uses the \emph{parse} function)
 #' @param title Graph title
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param dec Number of cells
@@ -128,7 +128,7 @@ conjdic=function(trat,
                    aes(x=var2,
                        y=var1,
                        fill=resp1))+
-    geom_tile(color="gray50",size=1)+
+    geom_tile(color="gray50",linewidth=1)+
     scale_x_discrete(position = "top")+
     scale_fill_distiller(palette = "RdBu",direction = 1)+
     ylab("Numerator")+xlab("Denominator")+
@@ -174,13 +174,13 @@ conjdic=function(trat,
   if(norm=="sf"){norm1=nortest::sf.test(d$residuals)}
 
   if(homog=="bt"){
-    homog1 = bartlett.test(d$res ~ trat)
+    homog1 = bartlett.test(d$res ~ tratamento)
     statistic=homog1$statistic
     phomog=homog1$p.value
     method=paste("Bartlett test","(",names(statistic),")",sep="")
   }
   if(homog=="levene"){
-    homog1 = levenehomog(d$res~trat)
+    homog1 = levenehomog(d$res~tratamento)
     statistic=homog1$`F value`[1]
     phomog=homog1$`Pr(>F)`[1]
     method="Levene's Test (center = median)(F)"
@@ -223,7 +223,7 @@ conjdic=function(trat,
   rownames(homoge)=""
   print(homoge)
   cat("\n")
-  message(if(homog1$p.value>0.05){black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, the variances can be considered homogeneous")}
+  message(if(homog1$p.value[1]>0.05){black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, the variances can be considered homogeneous")}
       else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, the variances are not homogeneous\n"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Independence from errors")))
@@ -270,14 +270,14 @@ conjdic=function(trat,
           if(mcomp=="lsd"){tukey[[i]]=LSD(aov1,"tratamento",alpha = alpha.t)$groups
           comp=LSD(aov1,"tratamento",alpha = alpha.t)$groups}
           if(mcomp=="sk"){
-            anova=anova(aov1)
+            anova3=anova(aov1)
             data=dados[dados$local==levels(dados$local)[i],]
-            nrep=table(data$trat)[1]
-            medias=sort(tapply(data$resp,data$trat,mean),decreasing = TRUE)
+            nrep=table(data$tratamento)[1]
+            medias=sort(tapply(data$resp,data$tratamento,mean),decreasing = TRUE)
             letra=scottknott(means = medias,
-                             df1 = anova$Df[2],
+                             df1 = anova3$Df[2],
                              nrep = nrep,
-                             QME = anova$`Mean Sq`[2],
+                             QME = anova3$`Mean Sq`[2],
                              alpha = alpha.t)
             letra1=data.frame(resp=medias,groups=letra)
             tukey[[i]]=letra1
@@ -329,7 +329,8 @@ conjdic=function(trat,
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
       cat(green(bold("-----------------------------------------------------------------\n")))
-      print(tukey)}
+      print(tukey)
+      print(grafico)}
     if(quali==FALSE){
         for(i in 1:length(levels(local))){
         data=dados[dados$local==levels(dados$local)[i],]
@@ -344,6 +345,7 @@ conjdic=function(trat,
                            theme=theme,
                            posi="top",
                            se=errorbar)[[1]]
+        print(grafico)
         graficos[[i]]=grafico[[1]]}}}
   if(a$`Pr(>F)`[1] < alpha.f && qmresmedio < homog.value){
     GLconj=datas$Df[4]
@@ -417,6 +419,7 @@ conjdic=function(trat,
                   legend.position = "none")#}
         graficos[[i]]=grafico}
         }
+      print(grafico)
       print(anova,na.print = "")
       teste=if(mcomp=="tukey"){"Tukey HSD"}else{
         if(mcomp=="sk"){"Scott-Knott"}else{
@@ -441,6 +444,7 @@ conjdic=function(trat,
                            DFres = GLconj,
                            posi="top",
                            se=errorbar)[[1]]
+        print(grafico)
         graficos[[i]]=grafico[[1]]}}
   }
   if(a$`Pr(>F)`[1] > alpha.f && qmresmedio < homog.value){
@@ -520,7 +524,7 @@ conjdic=function(trat,
 
     cat(green(bold("-----------------------------------------------------------------\n")))
     print(tukeyjuntos)
-    # print(grafico1)
+    print(grafico1)
     # graficos=list(grafico1)
     }
     if(quali==FALSE){grafico1=polynomial(tratnum,
@@ -534,14 +538,26 @@ conjdic=function(trat,
                            DFres = GLconj,
                            posi="top",
                            se=errorbar)
+    print(grafico1)
     }
     graficos=list(grafico1)
 
     }
   cat(if(transf=="1"){}else{blue("\nNOTE: resp = transformed means; respO = averages without transforming\n")})
 
-  if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test and try to transform the data"))}
-  if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test"))}
+  if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 && homog1$p.value[1]<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test and try to transform the data"))}
+  if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value[1]<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test"))}
   # print(graficos)
-  (graph=as.list(graficos))
+  # print(graficos)
+  graph=list(plot=graficos,
+             trat=trat,
+             ylab=ylab,
+             qmresmedio=qmresmedio,
+             datas=datas,
+             homog.value=homog.value,
+             homog=homog1,
+             indep=indep,
+             norm=norm1,
+             alpha.f=alpha.f,
+             dadosm=dadosm)
 }
