@@ -7,7 +7,7 @@
 #' @param ylab Variable response name (Accepts the \emph{expression}() function)
 #' @param xlab Treatments name (Accepts the \emph{expression}() function)
 #' @param theme ggplot theme (\emph{default} is theme_classic())
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @return The function returns a new graphical approach to correlation.
@@ -65,7 +65,7 @@ cor_ic=function(data,
   vari=1:combs
   pvalor=1:combs
   for(i in 1:combs){
-    vari[i]=paste(colnames(df_list[[i]])[1],"x",
+    vari[i]=paste(colnames(df_list[[i]])[1],"\u00D7",
                   colnames(df_list[[i]])[2])
     combin[i]=cor.test(unlist(df_list[[i]][,1]),
                        unlist(df_list[[i]][,2]),method = method)$estimate
