@@ -1,7 +1,7 @@
 #' Analysis: Randomized block design with an additional treatment for quantitative factor
 #'
 #' @description Statistical analysis of experiments conducted in a randomized block design with an additional treatment and balanced design with a factor considering the fixed model.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param trat Numerical or complex vector with treatments
@@ -13,8 +13,8 @@
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param grau Degree of polynomial in case of quantitative factor (\emph{default} is 1)
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
+#' @param xlab Treatments name (this argument uses the \emph{parse} function)
 #' @param family Font family
 #' @param pointsize Point size
 #' @param linesize line size (Trendline and Error Bar)
@@ -100,7 +100,7 @@ dbc.ad=function(trat,
     scale_x_continuous(breaks=1:length(respad))+
     theme_classic()+theme(axis.text.y = element_text(size=12),
                           axis.text.x = element_blank())+
-    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",size=1)
+    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",linewidth=1)
   print(residplot)
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Normality of errors")))
@@ -151,10 +151,10 @@ dbc.ad=function(trat,
   cat(green(bold("Analysis of Variance")))
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   print(anava1)
-  a=AgroR::polynomial(trat,response,DFres = anava1$Df[4],
+  polynomial(trat,response,DFres = anava1$Df[4],
                       SSq = anava1$`Sum Sq`[4],
-                      ylab = ylab,
-                      xlab=xlab,
+                      ylab = parse(text=ylab),
+                      xlab = parse(text=xlab),
                       theme = theme,
                       point = point,
                       grau = grau,
@@ -162,5 +162,4 @@ dbc.ad=function(trat,
                       family = family,
                       pointsize = pointsize,
                       linesize = linesize,
-                      width.bar = width.bar)
-  print(a[[1]])}
+                      width.bar = width.bar)}
