@@ -1,6 +1,6 @@
 #' Analysis: Randomized block design
 #'
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @description This is a function of the AgroR package for statistical analysis of experiments conducted in a randomized block and balanced design with a factor considering the fixed model. The function presents the option to use non-parametric method or transform the dataset.
@@ -21,8 +21,8 @@
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param sup Number of units above the standard deviation or average bar on the graph
 #' @param CV Plotting the coefficient of variation and p-value of Anova (\emph{default} is TRUE)
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
+#' @param xlab Treatments name (this argument uses the \emph{parse} function)
 #' @param fill Defines chart color (to generate different colors for different treatments, define fill = "trat")
 #' @param angle x-axis scale text rotation
 #' @param family Font family
@@ -39,6 +39,8 @@
 #' @param labelsize Label size
 #' @param angle.label label angle
 #' @param ylim Define a numerical sequence referring to the y scale. You can use a vector or the `seq` command.
+#' @param print.on Print output
+#' @param plot.on Plot output
 #' @note Enable ggplot2 package to change theme argument.
 #' @note The ordering of the graph is according to the sequence in which the factor levels are arranged in the data sheet. The bars of the column and segment graphs are standard deviation.
 #' @note CV and p-value of the graph indicate coefficient of variation and p-value of the F test of the analysis of variance.
@@ -81,8 +83,7 @@
 #' # Example soybean
 #' #=============================
 #' data(soybean)
-#' with(soybean, DBC(cult, bloc, prod,
-#'                   ylab=expression("Grain yield"~(kg~ha^-1))))
+#' with(soybean, DBC(cult, bloc, prod,ylab="Grain yield (kg ha^-1)"))
 
 DBC=function(trat,
              block,
@@ -109,7 +110,7 @@ DBC=function(trat,
              angle=0,
              family="sans",
              dec=3,
-             width.column=NULL,
+             width.column=0.9,
              width.bar=0.3,
              addmean=TRUE,
              errorbar=TRUE,
@@ -117,7 +118,11 @@ DBC=function(trat,
              point="mean_sd",
              pointsize=5,
              angle.label=0,
-             ylim=NA){
+             ylim=NA,
+             print.on=TRUE,
+             plot.on=TRUE){
+  ylab=parse(text=gsub(" ","~",ylab))
+  xlab=parse(text=gsub(" ","~",xlab))
   requireNamespace("crayon")
   requireNamespace("ggplot2")
   requireNamespace("nortest")
@@ -173,41 +178,45 @@ DBC=function(trat,
     theme_classic()+
     theme(axis.text.y = element_text(size=12),
           axis.text.x = element_blank())+
-    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",size=1)
-  print(residplot)
+    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",linewidth=1)
+  if(plot.on==TRUE){
+    print(residplot)
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Normality of errors")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   normal=data.frame(Method=paste(norm1$method,"(",names(norm1$statistic),")",sep=""),
                     Statistic=norm1$statistic,
                     "p-value"=norm1$p.value)
   rownames(normal)=""
-  print(normal)
+  if(print.on==TRUE){
+    print(normal)
   cat("\n")
   message(if(norm1$p.value>0.05){
     black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, errors can be considered normal")}
     else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, errors do not follow a normal distribution"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Homogeneity of Variances")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   homoge=data.frame(Method=method,
                     Statistic=statistic,
                     "p-value"=phomog)
   rownames(homoge)=""
-  print(homoge)
+  if(print.on==TRUE){
+    print(homoge)
   cat("\n")
   message(if(homog1$p.value>0.05){
     black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, the variances can be considered homogeneous")}
     else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, the variances are not homogeneous"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Independence from errors")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   indepe=data.frame(Method=paste(indep$method,"(",
                                  names(indep$statistic),")",sep=""),
                     Statistic=indep$statistic,
                     "p-value"=indep$p.value)
   rownames(indepe)=""
-  print(indepe)
+  if(print.on==TRUE){
+    print(indepe)
   cat("\n")
   message(if(indep$p.value>0.05){
     black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, errors can be considered independent")}
@@ -223,11 +232,12 @@ DBC=function(trat,
   cat("\n")
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Analysis of Variance")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   anava1=as.matrix(data.frame(anava))
   colnames(anava1)=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
   rownames(anava1)=c("Treatment","Block","Residuals")
-  print(anava1,na.print = "")
+  if(print.on==TRUE){
+    print(anava1,na.print = "")
   cat("\n")
   message(if (a$`Pr(>F)`[1]<alpha.f){
     black("As the calculated p-value, it is less than the 5% significance level. The hypothesis H0 of equality of means is rejected. Therefore, at least two treatments differ")}
@@ -240,7 +250,7 @@ DBC=function(trat,
         if(mcomp=="duncan"){"Duncan"}}}}
   cat(green(italic(paste("Multiple Comparison Test:",teste))))
   }else{cat(green(bold("Regression")))}
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   if(quali==TRUE){
   if(mcomp=="tukey"){
     letra <- TUKEY(b, "trat", alpha=alpha.t)
@@ -262,13 +272,14 @@ DBC=function(trat,
       letra1 <- letra$groups; colnames(letra1)=c("resp","groups")}
     media = tapply(response, trat, mean, na.rm=TRUE)
   if(transf=="1"){letra1}else{letra1$respO=media[rownames(letra1)]}
-  print(if(a$`Pr(>F)`[1]<alpha.f){letra1}else{"H0 is not rejected"})
+    if(print.on==TRUE){
+      print(if(a$`Pr(>F)`[1]<alpha.f){letra1}else{"H0 is not rejected"})
   cat("\n")
   cat(if(transf=="1"){}else{blue("resp = transformed means; respO = averages without transforming")})
   if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 &&homog1$p.value<0.05){
     message("\nYour analysis is not valid, suggests using a non-parametric \ntest and try to transform the data")}
   else{}
-  if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric \ntest"))}else{}
+  if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric \ntest"))}else{}}
   if(point=="mean_sd"){
     dadosm=data.frame(letra1,
                       media=tapply(response, trat, mean, na.rm=TRUE)[rownames(letra1)],
@@ -352,8 +363,8 @@ DBC=function(trat,
     geom_text(data=dadosm2,aes(y=superior,label=letra),
               family=family,size=labelsize,angle=angle.label, hjust=hjust)}
   grafico=grafico+theme+
-    ylab(ylab)+
-    xlab(xlab)+
+    ylab(parse(text=ylab))+
+    xlab(parse(text=xlab))+
     theme(text = element_text(size=textsize,color="black",family=family),
           axis.text = element_text(size=textsize,color="black",family=family),
           axis.title = element_text(size=textsize,color="black",family=family),
@@ -368,14 +379,15 @@ DBC=function(trat,
   }
   if(quali==FALSE){
     trat=trat1
-    if(grau==1){graph=polynomial(trat,response, grau = 1,xlab=xlab,ylab=ylab,textsize=textsize, family=family,posi=posi,point=point,SSq = a$`Sum Sq`[3],DFres = a$Df[3],pointsize = pointsize)}
-    if(grau==2){graph=polynomial(trat,response, grau = 2,xlab=xlab,ylab=ylab,textsize=textsize, family=family,posi=posi,point=point,SSq = a$`Sum Sq`[3],DFres = a$Df[3],pointsize = pointsize)}
-    if(grau==3){graph=polynomial(trat,response, grau = 3,xlab=xlab,ylab=ylab,textsize=textsize, family=family,posi=posi,point=point,SSq = a$`Sum Sq`[3],DFres = a$Df[3],pointsize = pointsize)}
+    if(grau==1){graph=polynomial(trat,response, grau = 1,xlab=parse(text=xlab),ylab=parse(text=ylab),textsize=textsize, family=family,posi=posi,point=point,SSq = a$`Sum Sq`[3],DFres = a$Df[3],pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
+    if(grau==2){graph=polynomial(trat,response, grau = 2,xlab=parse(text=xlab),ylab=parse(text=ylab),textsize=textsize, family=family,posi=posi,point=point,SSq = a$`Sum Sq`[3],DFres = a$Df[3],pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
+    if(grau==3){graph=polynomial(trat,response, grau = 3,xlab=parse(text=xlab),ylab=parse(text=ylab),textsize=textsize, family=family,posi=posi,point=point,SSq = a$`Sum Sq`[3],DFres = a$Df[3],pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
     grafico=graph[[1]]
     if(is.na(ylim[1])==FALSE){
       grafico=grafico+scale_y_continuous(breaks = ylim,
                                          limits = c(min(ylim),max(ylim)))}
-    print(grafico)
+    if(plot.on==TRUE){
+      print(grafico)}
 
   }}
   if(test=="noparametric"){
@@ -517,8 +529,10 @@ DBC=function(trat,
     }
     trat=trat
     bloco=block
+    resp=response
     fried=friedman(bloco,trat,response,alpha=alpha.t)
-    cat(green(bold("\n\n-----------------------------------------------------------------\n")))
+    if(print.on==TRUE){
+      cat(green(bold("\n\n-----------------------------------------------------------------\n")))
     cat(green(italic("Statistics")))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     print(fried$statistics)
@@ -529,11 +543,12 @@ DBC=function(trat,
     cat(green(bold("\n\n-----------------------------------------------------------------\n")))
     cat(green(italic(paste("Multiple Comparison Test:","LSD"))))
 
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     saida=cbind(fried$means[rownames(fried$means),
                             c(1,3)],fried$groups[rownames(fried$means),])
     colnames(saida)=c("Mean","SD","Rank","Groups")
-    print(saida)
+    if(print.on==TRUE){
+      print(saida)}
     dadosm=data.frame(fried$means,fried$groups[rownames(fried$means),])
     dadosm$trats=factor(rownames(dadosm),levels = unique(trat))
     dadosm$media=tapply(response,trat,mean, na.rm=TRUE)[rownames(fried$means)]
@@ -612,8 +627,8 @@ DBC=function(trat,
                     label=letra),family=family,size=labelsize,angle=angle.label, hjust=hjust)}
 
     grafico=grafico+theme+
-      ylab(ylab)+
-      xlab(xlab)+
+      ylab(parse(text=ylab))+
+      xlab(parse(text=xlab))+
       theme(text = element_text(size=textsize,color="black",family=family),
             axis.text = element_text(size=textsize,color="black",family=family),
             axis.title = element_text(size=textsize,color="black",family=family),
@@ -624,6 +639,32 @@ DBC=function(trat,
   if(is.na(ylim[1])==FALSE){
     grafico=grafico+scale_y_continuous(breaks = ylim,
                                        limits = c(min(ylim),max(ylim)))}
-  if(quali==TRUE){print(grafico)}
-  grafico=list(grafico)
+  if(quali==TRUE){if(plot.on==TRUE){
+    print(grafico)}}
+  output=list(
+      plot=grafico,
+      resp=resp,
+      trat=trat,
+      bloco=bloco,
+      resp=resp,
+      response=response,
+      test=test,
+      transf=transf,
+      sup=sup,
+      fill=fill,
+      textsize=textsize,
+      labelsize=labelsize,
+      width.column=width.column,
+      width.bar=width.bar,
+      errorbar=errorbar,
+      xlab=xlab,
+      ylab=ylab,
+      geom=geom,
+      family=family,
+      dadosm=if(quali==T & (geom == "point" | geom=="bar")){dadosm}else{if(geom=="box"){dadosm2}else{NA}},
+      anova=if(test=="parametric"){a}else{NA},
+      fried=if(test=="noparametric"){fried$statistics}else{NA},
+      norm=if(test=="parametric"){norm1}else{NA},
+      homog=if(test=="parametric"){homog1}else{NA},
+      indep=if(test=="parametric"){indep}else{NA})
   }
