@@ -1,7 +1,7 @@
 #' Analysis: Completely randomized design
 #'
 #' @description Statistical analysis of experiments conducted in a completely randomized and balanced design with a factor considering the fixed model. The function presents the option to use non-parametric method or transform the dataset.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param trat Numerical or complex vector with treatments
@@ -22,8 +22,8 @@
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param sup Number of units above the standard deviation or average bar on the graph
 #' @param CV Plotting the coefficient of variation and p-value of Anova (\emph{default} is TRUE)
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
+#' @param xlab Treatments name (this argument uses the \emph{parse} function)
 #' @param textsize Font size
 #' @param labelsize Label size
 #' @param fill Defines chart color (to generate different colors for different treatments, define fill = "trat")
@@ -39,6 +39,8 @@
 #' @param pointsize Point size
 #' @param angle.label label angle
 #' @param ylim Define a numerical sequence referring to the y scale. You can use a vector or the `seq` command.
+#' @param print.on Print output
+#' @param plot.on Plot output
 #' @import ggplot2
 #' @import stats
 #' @import multcompView
@@ -97,29 +99,27 @@
 #' library(AgroR)
 #' data(pomegranate)
 #'
-#' with(pomegranate, DIC(trat, WL, ylab = "Weight loss (%)")) # tukey
-#' with(pomegranate, DIC(trat, WL, mcomp = "sk", ylab = "Weight loss (%)"))
-#' with(pomegranate, DIC(trat, WL, mcomp = "duncan", ylab = "Weight loss (%)"))
+#' with(pomegranate, DIC(trat, WL, ylab = "Weight loss ('%')")) # tukey
+#' with(pomegranate, DIC(trat, WL, mcomp = "sk", ylab = "Weight loss ('%')"))
+#' with(pomegranate, DIC(trat, WL, mcomp = "duncan", ylab = "Weight loss ('%')"))
 #'
 #' #=============================
 #' # Kruskal-Wallis
 #' #=============================
-#' with(pomegranate, DIC(trat, WL, test = "noparametric", ylab = "Weight loss (%)"))
+#' with(pomegranate, DIC(trat, WL, test = "noparametric", ylab = "Weight loss ('%')"))
 #'
 #'
 #' #=============================
 #' # chart type
 #' #=============================
-#' with(pomegranate, DIC(trat, WL, geom="point", ylab = "Weight loss (%)"))
-#' with(pomegranate, DIC(trat, WL, ylab = "Weight loss (%)", xlab="Treatments"))
+#' with(pomegranate, DIC(trat, WL, geom="point", ylab = "Weight loss ('%')"))
+#' with(pomegranate, DIC(trat, WL, ylab = "Weight loss ('%')", xlab="Treatments"))
 #'
 #' #=============================
 #' # quantitative factor
 #' #=============================
 #' data("phao")
-#' with(phao, DIC(dose,comp,quali=FALSE,grau=2,
-#'                xlab = expression("Dose"~(g~vase^-1)),
-#'                ylab="Leaf length (cm)"))
+#' with(phao, DIC(dose,comp,quali=FALSE,grau=2,xlab = "Dose (g vase^-1)",ylab="Leaf length (cm)"))
 #'
 #' #=============================
 #' # data transformation
@@ -153,7 +153,7 @@ DIC <- function(trat,
                 textsize=12,
                 labelsize=4,
                 dec=3,
-                width.column=NULL,
+                width.column=0.9,
                 width.bar=0.3,
                 addmean=TRUE,
                 errorbar=TRUE,
@@ -161,7 +161,11 @@ DIC <- function(trat,
                 point="mean_sd",
                 pointsize=5,
                 angle.label=0,
-                ylim=NA){
+                ylim=NA,
+                print.on=TRUE,
+                plot.on=TRUE){
+  ylab=gsub(" ","~",ylab)
+  xlab=gsub(" ","~",xlab)
   if(is.na(sup==TRUE)){sup=0.1*mean(response)}
   if(angle.label==0){hjust=0.5}else{hjust=0}
   requireNamespace("nortest")
@@ -216,41 +220,42 @@ DIC <- function(trat,
       scale_x_continuous(breaks=1:length(resids))+
       theme_classic()+theme(axis.text.y = element_text(size=12),
                             axis.text.x = element_blank())+
-      geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",size=1)
-    print(residplot)
+      geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",linewidth=1)
+    if(plot.on==TRUE){print(residplot)}
+    if(print.on==TRUE){
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     cat(green(bold("Normality of errors")))
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     normal=data.frame(Method=paste(norm1$method,"(",names(norm1$statistic),")",sep=""),
                       Statistic=norm1$statistic,
                       "p-value"=norm1$p.value)
     rownames(normal)=""
-    print(normal)
+    if(print.on==TRUE){print(normal)
     cat("\n")
     message(if(norm1$p.value>0.05){
       black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, errors can be considered normal")}
       else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, errors do not follow a normal distribution"})
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     cat(green(bold("Homogeneity of Variances")))
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     homoge=data.frame(Method=method,
                       Statistic=statistic,
                       "p-value"=phomog)
     rownames(homoge)=""
-    print(homoge)
+    if(print.on==TRUE){print(homoge)
     cat("\n")
     message(if(homog1$p.value>0.05){
       black("As the calculated p-value is greater than the 5% significance level,hypothesis H0 is not rejected. Therefore, the variances can be considered homogeneous")}
       else {"As the calculated p-value is less than the 5% significance level, H0 is rejected.Therefore, the variances are not homogeneous"})
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     cat(green(bold("Independence from errors")))
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     indepe=data.frame(Method=paste(indep$method,"(",
                                    names(indep$statistic),")",sep=""),
                       Statistic=indep$statistic,
                       "p-value"=indep$p.value)
     rownames(indepe)=""
-    print(indepe)
+    if(print.on==TRUE){print(indepe)
     cat("\n")
     message(if(indep$p.value>0.05){
       black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, errors can be considered independent")}
@@ -266,23 +271,24 @@ DIC <- function(trat,
     cat("\n")
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     cat(green(bold("Analysis of Variance")))
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     anava1=as.matrix(data.frame(anava))
     colnames(anava1)=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
     rownames(anava1)=c("Treatment","Residuals")
-    print(anava1,na.print = "")
+    if(print.on==TRUE){print(anava1,na.print = "")
     cat("\n\n")
     message(if (a$`Pr(>F)`[1]<alpha.f){
       black("As the calculated p-value, it is less than the 5% significance level.The hypothesis H0 of equality of means is rejected. Therefore, at least two treatments differ")}
       else {"As the calculated p-value is greater than the 5% significance level, H0 is not rejected"})
-    cat(green(bold("\n\n-----------------------------------------------------------------\n")))
-    if(quali==TRUE){
+    cat(green(bold("\n\n-----------------------------------------------------------------\n")))}
+    if(print.on==TRUE){
+      if(quali==TRUE){
       teste=if(mcomp=="tukey"){"Tukey HSD"}else{
         if(mcomp=="sk"){"Scott-Knott"}else{
           if(mcomp=="lsd"){"LSD-Fischer"}else{
             if(mcomp=="duncan"){"Duncan"}}}}
-    cat(green(italic(paste("Multiple Comparison Test:",teste))))}else{cat(green(bold("Regression")))}
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+        cat(green(italic(paste("Multiple Comparison Test:",teste))))}else{cat(green(bold("Regression")))}
+      cat(green(bold("\n-----------------------------------------------------------------\n")))}
     if(quali==TRUE){
       if(mcomp=="tukey"){
         letra <- TUKEY(b, "trat", alpha=alpha.t)
@@ -304,14 +310,15 @@ DIC <- function(trat,
         letra1 <- letra$groups; colnames(letra1)=c("resp","groups")}
       media = tapply(response, trat, mean, na.rm=TRUE)
       if(transf=="1"){letra1}else{letra1$respO=media[rownames(letra1)]}
-      print(if(a$`Pr(>F)`[1]<alpha.f){letra1}else{"H0 is not rejected"})
+      if(print.on==TRUE){print(if(a$`Pr(>F)`[1]<alpha.f){letra1}else{"H0 is not rejected"})
       cat("\n")
       message(if(transf=="1"){}else{blue("\nNOTE: resp = transformed means; respO = averages without transforming\n")})
       if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 &&homog1$p.value<0.05){
         message("\nYour analysis is not valid, suggests using a non-parametric test and try to transform the data")
       }
       else{}
-      if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){cat(red("\nWarning!!! Your analysis is not valid, suggests using a non-parametric test"))}else{}
+      if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){
+        cat(red("\nWarning!!! Your analysis is not valid, suggests using a non-parametric test"))}else{}}
       if(point=="mean_sd"){
         dadosm=data.frame(letra1,
                           media=tapply(response, trat, mean, na.rm=TRUE)[rownames(letra1)],
@@ -396,8 +403,8 @@ DIC <- function(trat,
                     family = family,size=labelsize,angle=angle.label, hjust=hjust)}
       grafico=grafico+
         theme+
-        ylab(ylab)+
-        xlab(xlab)+
+        ylab(parse(text=ylab))+
+        xlab(parse(text=xlab))+
         theme(text = element_text(size=textsize,color="black", family = family),
               axis.text = element_text(size=textsize,color="black", family = family),
               axis.title = element_text(size=textsize,color="black", family = family),
@@ -411,21 +418,22 @@ DIC <- function(trat,
       if(is.na(ylim[1])==FALSE){
         grafico=grafico+scale_y_continuous(breaks = ylim,
                                            limits = c(min(ylim),max(ylim)))}
-      grafico=as.list(grafico)
+      # grafico=as.list(grafico)
     }
     if(quali==FALSE){
       trat=trat1
       # trat=as.numeric(as.character(trat))
-      if(grau==1){graph=polynomial(trat,response, grau = 1,textsize=textsize,xlab=xlab,ylab=ylab, family=family,posi=posi,point=point,pointsize = pointsize)}
-      if(grau==2){graph=polynomial(trat,response, grau = 2,textsize=textsize,xlab=xlab,ylab=ylab, family=family,posi=posi,point=point,pointsize = pointsize)}
-      if(grau==3){graph=polynomial(trat,response, grau = 3,textsize=textsize,xlab=xlab,ylab=ylab, family=family,posi=posi,point=point,pointsize = pointsize)}
+      if(grau==1){graph=polynomial(trat,response, grau = 1,textsize=textsize,xlab=parse(text=xlab),ylab=parse(text=ylab), family=family,posi=posi,point=point,pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
+      if(grau==2){graph=polynomial(trat,response, grau = 2,textsize=textsize,xlab=parse(text=xlab),ylab=parse(text=ylab), family=family,posi=posi,point=point,pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
+      if(grau==3){graph=polynomial(trat,response, grau = 3,textsize=textsize,xlab=parse(text=xlab),ylab=parse(text=ylab), family=family,posi=posi,point=point,pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
       grafico=graph[[1]]
       if(is.na(ylim[1])==FALSE){
         grafico=grafico+scale_y_continuous(breaks = ylim,
                                            limits = c(min(ylim),max(ylim)))}
-      print(grafico)
+      if(plot.on==TRUE){print(grafico)}
     }}
   if(test=="noparametric"){
+    resp=response
     kruskal=function (y,
                       trt,
                       alpha = 0.05,
@@ -480,7 +488,7 @@ DIC <- function(trat,
       MSerror <- S * ((N - 1 - H)/(N - ntr))
       means[, 2] <- means[, 2]/means[, 3]
       if(console){cat(paste(name.t, ",", sep = ""), " means of the ranks\n\n")
-        print(data.frame(row.names = means[, 1], means[, -1]))
+        if(print.on==TRUE){print(data.frame(row.names = means[, 1], means[, -1]))}
         cat("\nPost Hoc Analysis\n")}
       if (p.adj != "none") {
         if(console)cat("\nP value adjustment method:", p.adj)
@@ -546,8 +554,9 @@ DIC <- function(trat,
       if (!group) {
         groups<-NULL
         if(console){
-          cat("\nComparison between treatments mean of the ranks.\n\n")
-          print(comparison)
+          if(print.on==TRUE){
+            cat("\nComparison between treatments mean of the ranks.\n\n")
+            print(comparison)}
         }
       }
       if (group) {
@@ -565,8 +574,8 @@ DIC <- function(trat,
         groups <- ordenacao(means[, 1], means[, 2],alpha, Q, console)
         names(groups)[1]<-name.y
         if(console) {
-          cat("\nTreatments with the same letter are not significantly different.\n\n")
-          print(groups)
+          if(print.on==TRUE){cat("\nTreatments with the same letter are not significantly different.\n\n")
+          print(groups)}
         }
       }
       ranks=means
@@ -586,7 +595,8 @@ DIC <- function(trat,
       krusk1=dunn(trat, response, method = p.adj, alpha=alpha.t)
       krusk$groups=krusk$groups[unique(trat),]
       krusk$groups$groups=krusk1$`Post-hoc`$dunn}
-    cat(green(bold("\n\n-----------------------------------------------------------------\n")))
+    if(print.on==TRUE){
+      cat(green(bold("\n\n-----------------------------------------------------------------\n")))
     cat(green(italic("Statistics")))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     print(krusk$statistics)
@@ -596,10 +606,10 @@ DIC <- function(trat,
     print(krusk$parameters)
     cat(green(bold("\n\n-----------------------------------------------------------------\n")))
     cat(green(italic(paste("Multiple Comparison Test:","LSD"))))
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    cat(green(bold("\n-----------------------------------------------------------------\n")))}
     saida=cbind(krusk$means[,c(1,3)],krusk$groups[rownames(krusk$means),])
     colnames(saida)=c("Mean","SD","Rank","Groups")
-    print(saida)
+    if(print.on==TRUE){print(saida)}
     dadosm=data.frame(krusk$means,krusk$groups[rownames(krusk$means),])
     dadosm$trats=factor(rownames(dadosm),levels = unique(trat))
     dadosm$media=tapply(response,trat,mean, na.rm=TRUE)[rownames(krusk$means)]
@@ -683,8 +693,8 @@ DIC <- function(trat,
                       label=letra),
                   family = family,angle=angle.label, size=labelsize,hjust=hjust)}
     grafico=grafico+theme+
-      ylab(ylab)+
-      xlab(xlab)+
+      ylab(parse(text=ylab))+
+      xlab(parse(text=xlab))+
       theme(text = element_text(size=textsize,color="black", family = family),
             axis.title = element_text(size=textsize,color="black", family = family),
             axis.text = element_text(size=textsize,color="black", family = family),
@@ -695,6 +705,29 @@ DIC <- function(trat,
 
     if(angle !=0){grafico=grafico+theme(axis.text.x=element_text(hjust = 1.01,angle = angle))}
   }
-  if(quali==TRUE){print(grafico)}
-  graficos=list(grafico)#[[1]]
+  if(quali==TRUE){if(plot.on==TRUE){print(grafico)}}
+  output=list(plot=grafico,
+       resp=resp,
+       response=response,
+       trat=trat,
+       test=test,
+       transf=transf,
+       sup=sup,
+       textsize=textsize,
+       labelsize=labelsize,
+       fill=fill,
+       width.column=width.column,
+       width.bar=width.bar,
+       errorbar=errorbar,
+       geom=geom,
+       xlab=xlab,
+       ylab=ylab,
+       family=family,
+       dadosm=if(quali==T & (geom == "point" | geom=="bar")){dadosm}else{if(geom=="box"){dadosm2}else{NA}},
+       anova=if(test=="noparametric"){NA}else{a},
+       krusk=if(test=="noparametric"){krusk}else{NA},
+       norm=if(test=="parametric"){norm1}else{NA},
+       homog=if(test=="parametric"){homog1}else{NA},
+       indep=if(test=="parametric"){indep}else{NA})
+  # graficos=grafico#list(grafico)#[[1]]
 }
