@@ -1,7 +1,7 @@
 #' Analysis: Completely randomized design evaluated over time
 #'
 #' @description Function of the AgroR package for the analysis of experiments conducted in a completely randomized, qualitative, uniform qualitative design with multiple assessments over time, however without considering time as a factor.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param trat Numerical or complex vector with treatments
@@ -10,8 +10,8 @@
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
 #' @param mcomp Multiple comparison test (Tukey (\emph{default}), LSD ("lsd"), Scott-Knott ("sk"), Duncan ("duncan") and Kruskal-Wallis ("kw"))
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab treatments name (Accepts the \emph{expression}() function)
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
+#' @param xlab treatments name (this argument uses the \emph{parse} function)
 #' @param fill Defines chart color (to generate different colors for different treatments, define fill = "trat")
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param error Add error bar
@@ -84,6 +84,9 @@ DICT=function(trat,
               posi=c(0.1,0.8),
               xnumeric=FALSE,
               all.letters=FALSE){
+  ylab=parse(text=gsub(" ","~",ylab))
+  xlab=parse(text=gsub(" ","~",xlab))
+  legend=parse(text=gsub(" ","~",legend))
   requireNamespace("crayon")
   requireNamespace("ggplot2")
   requireNamespace("nortest")
@@ -452,8 +455,8 @@ grafico=ggplot(dadosm,aes(y=media,
                  group=factor(trat,levels=unique(as.character(trat)))),size=pointsize)+
   geom_line(aes(lty=factor(trat,levels=unique(as.character(trat))),
                 group=factor(trat,levels=unique(as.character(trat)))),size=0.8)+
-  ylab(ylab)+
-  xlab(xlab)+theme+
+  ylab(parse(text=ylab))+
+  xlab(parse(text=xlab))+theme+
   theme(text = element_text(size=textsize,color="black", family = family),
         axis.title = element_text(size=textsize,color="black", family = family),
         axis.text = element_text(size=textsize,color="black", family = family),
@@ -485,8 +488,8 @@ grafico=ggplot(dadosm,aes(y=media,
                           x=as.factor(time),
                           fill=factor(trat,levels = unique(trat))))+
   geom_col(position = "dodge",color="black")+
-  ylab(ylab)+
-  xlab(xlab)+theme+
+  ylab(parse(text=ylab))+
+  xlab(parse(text=xlab))+theme+
   theme(text = element_text(size=textsize,color="black", family = family),
         axis.title = element_text(size=textsize,color="black", family = family),
         axis.text = element_text(size=textsize,color="black", family = family),
@@ -514,7 +517,8 @@ if(addmean==TRUE && error==TRUE){grafico=grafico+
 }
 if(fill=="gray"){grafico=grafico+scale_fill_grey(start = 1, end = 0.1)}
 if(is.na(ylim[1])==FALSE){grafico=grafico+scale_y_continuous(breaks = ylim)}
-graficos=as.list(grafico)
+# graficos=as.list(grafico)
 print(grafico)
+output=list(plot=grafico,fill=fill,sup=sup,labelsize=labelsize,family=family)
 }
 
