@@ -1,7 +1,7 @@
 #' Analysis: Latin square design
 #'
 #' @description This is a function of the AgroR package for statistical analysis of experiments conducted in Latin Square and balanced design with a factor considering the fixed model.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param trat Numerical or complex vector with treatments
@@ -38,6 +38,8 @@
 #' @param pointsize Point size
 #' @param angle.label label angle
 #' @param ylim Define a numerical sequence referring to the y scale. You can use a vector or the `seq` command.
+#' @param print.on Print output
+#' @param plot.on Plot output
 #' @note The ordering of the graph is according to the sequence in which the factor levels are arranged in the data sheet. The bars of the column and segment graphs are standard deviation.
 #' @note CV and p-value of the graph indicate coefficient of variation and p-value of the F test of the analysis of variance.
 #' @note In the final output when transformation (transf argument) is different from 1, the columns resp and respo in the mean test are returned, indicating transformed and non-transformed mean, respectively.
@@ -91,7 +93,7 @@ DQL=function(trat,
              angle=0,
              family="sans",
              dec=3,
-             width.column=NULL,
+             width.column=0.9,
              width.bar=0.3,
              addmean=TRUE,
              errorbar=TRUE,
@@ -99,8 +101,12 @@ DQL=function(trat,
              point="mean_sd",
              pointsize=5,
              angle.label=0,
-             ylim=NA)
-{if(is.na(sup==TRUE)){sup=0.2*mean(response)}
+             ylim=NA,
+             print.on=TRUE,
+             plot.on=TRUE){
+  ylab=parse(text=gsub(" ","~",ylab))
+  xlab=parse(text=gsub(" ","~",xlab))
+  if(is.na(sup==TRUE)){sup=0.2*mean(response)}
   if(angle.label==0){hjust=0.5}else{hjust=0}
   requireNamespace("crayon")
   requireNamespace("ggplot2")
@@ -158,41 +164,45 @@ DQL=function(trat,
     scale_x_continuous(breaks=1:length(resids))+
     theme_classic()+theme(axis.text.y = element_text(size=12),
                           axis.text.x = element_blank())+
-    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",size=1)
-  print(residplot)
+    geom_hline(yintercept = c(0,-3,3),lty=c(1,2,2),color="red",linewidth=1)
+  if(plot.on==TRUE){
+    print(residplot)
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Normality of errors (Shapiro-Wilk")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   normal=data.frame(Method=paste(norm1$method,"(",names(norm1$statistic),")",sep=""),
                     Statistic=norm1$statistic,
                     "p-value"=norm1$p.value)
   rownames(normal)=""
-  print(normal)
+  if(print.on==TRUE){
+    print(normal)
   cat("\n")
   message(if(norm1$p.value>0.05){
     black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, errors can be considered normal")}
     else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, errors do not follow a normal distribution"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Homogeneity of Variances")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   homoge=data.frame(Method=method,
                     Statistic=statistic,
                     "p-value"=phomog)
   rownames(homoge)=""
-  print(homoge)
+  if(print.on==TRUE){
+    print(homoge)
   cat("\n")
   message(if(homog1$p.value>0.05){
     black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, the variances can be considered homogeneous")}
     else {"As the calculated p-value is less than the 5% significance level, H0 is rejected. Therefore, the variances are not homogeneous"})
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Independence from errors")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   indepe=data.frame(Method=paste(indep$method,"(",
                                  names(indep$statistic),")",sep=""),
                     Statistic=indep$statistic,
                     "p-value"=indep$p.value)
   rownames(indepe)=""
-  print(indepe)
+  if(print.on==TRUE){
+    print(indepe)
   cat("\n")
   message(if(indep$p.value>0.05){
     black("As the calculated p-value is greater than the 5% significance level, hypothesis H0 is not rejected. Therefore, errors can be considered independent")}
@@ -208,11 +218,12 @@ DQL=function(trat,
   cat("\n")
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Analysis of Variance")))
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
   anava1=as.matrix(data.frame(anava))
   colnames(anava1)=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
   rownames(anava1)=c("Treatment","Line","Column","Residuals")
-  print(anava1,na.print = "")
+  if(print.on==TRUE){
+    print(anava1,na.print = "")
   cat("\n")
   message(if (a$`Pr(>F)`[1]<alpha.f){
     black("As the calculated p-value, it is less than the 5% significance level. The hypothesis H0 of equality of means is rejected. Therefore, at least two treatments differ")}
@@ -224,7 +235,7 @@ DQL=function(trat,
         if(mcomp=="duncan"){"Duncan"}}}}
   cat(green(italic(paste("Multiple Comparison Test:",teste))))
   }else{cat(green(bold("Regression")))}
-  cat(green(bold("\n-----------------------------------------------------------------\n")))
+  cat(green(bold("\n-----------------------------------------------------------------\n")))}
 
   # ================================
   # Comparação multipla
@@ -258,14 +269,16 @@ DQL=function(trat,
 
   media = tapply(response, trat, mean, na.rm=TRUE)
 
-  if(transf=="1"){letra1}else{letra1$respO=media[rownames(letra1)]}
+  if(print.on==TRUE){
+    if(transf=="1"){letra1}else{letra1$respO=media[rownames(letra1)]}
   print(if(a$`Pr(>F)`[1]<alpha.f){letra1}else{"H0 is not rejected"})
 
   cat("\n")
   message(if(transf=="1"){}else{blue("resp = transformed means; respO = averages without transforming")})
 
   if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 &&homog1$p.value<0.05){
-    message("\n \nWarning!!! Your analysis is not valid, suggests using a try to transform the data")}else{}
+    message("\n \nWarning!!! Your analysis is not valid, suggests using a try to transform the data")}else{}}
+
   if(point=="mean_sd"){
     dadosm=data.frame(letra1,
                       media=tapply(response, trat, mean, na.rm=TRUE)[rownames(letra1)],
@@ -356,8 +369,8 @@ DQL=function(trat,
               family=family,size=labelsize,angle=angle.label, hjust=hjust)}
 
   grafico=grafico+theme+
-    ylab(ylab)+
-    xlab(xlab)+
+    ylab(parse(text=ylab))+
+    xlab(parse(text=xlab))+
     theme(text = element_text(size=textsize,color="black",family=family),
           axis.text = element_text(size=textsize,color="black",family=family),
           axis.title = element_text(size=textsize,color="black",family=family),
@@ -373,9 +386,9 @@ DQL=function(trat,
 
   if(quali==FALSE){
     trat=trat1
-    if(grau==1){graph=polynomial(trat,response, grau = 1,xlab=xlab,ylab=ylab,textsize=textsize, family=family,posi=posi,point=point,SSq=a$`Sum Sq`[4],DFres = a$Df[4],pointsize = pointsize)}
-    if(grau==2){graph=polynomial(trat,response, grau = 2,xlab=xlab,ylab=ylab,textsize=textsize, family=family,posi=posi,point=point,SSq=a$`Sum Sq`[4],DFres = a$Df[4],pointsize = pointsize)}
-    if(grau==3){graph=polynomial(trat,response, grau = 3,xlab=xlab,ylab=ylab,textsize=textsize, family=family,posi=posi,point=point,SSq=a$`Sum Sq`[4],DFres = a$Df[4],pointsize = pointsize)}
+    if(grau==1){graph=polynomial(trat,response, grau = 1,xlab=parse(text=xlab),ylab=parse(text=ylab),textsize=textsize, family=family,posi=posi,point=point,SSq=a$`Sum Sq`[4],DFres = a$Df[4],pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
+    if(grau==2){graph=polynomial(trat,response, grau = 2,xlab=parse(text=xlab),ylab=parse(text=ylab),textsize=textsize, family=family,posi=posi,point=point,SSq=a$`Sum Sq`[4],DFres = a$Df[4],pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
+    if(grau==3){graph=polynomial(trat,response, grau = 3,xlab=parse(text=xlab),ylab=parse(text=ylab),textsize=textsize, family=family,posi=posi,point=point,SSq=a$`Sum Sq`[4],DFres = a$Df[4],pointsize = pointsize,print.on = print.on,plot.on = FALSE)}
     grafico=graph[[1]]
     if(is.na(ylim[1])==FALSE){
       grafico=grafico+scale_y_continuous(breaks = ylim,
@@ -383,6 +396,30 @@ DQL=function(trat,
     print(grafico)
 
   }
-  if(quali==TRUE){print(grafico)}
-  graficos=list(grafico)#[[1]]
+  if(quali==TRUE){if(plot.on==TRUE){
+    print(grafico)}}
+  output=list(plot=grafico,
+              resp=resp,
+              trat=trat,
+              line=line,
+              column=column,
+              test="parametric",
+              transf=transf,
+              fill=fill,
+              response=response,
+              sup=sup,
+              textsize=textsize,
+              xlab=xlab,
+              ylab=ylab,
+              labelsize=labelsize,
+              errorbar=errorbar,
+              width.column=width.column,
+              width.bar=width.bar,
+              geom=geom,
+              family=family,
+              dadosm=if(quali==T & geom == "point" | geom=="bar"){dadosm}else{if(geom=="box"){dadosm2}else{NA}},
+              anova=a,
+              norm=norm1,
+              homog=homog1,
+              indep=indep)
   }
