@@ -17,7 +17,7 @@
 #' @param labelsize Label size
 #' @param errorsize Errorbar size
 #' @param widthsize Width errorbar
-#' @param fontfamily font family
+#' @param family font family
 #' @note Do not use the "-" symbol or space in treatment names
 #' @return I return the Dunnett test for experiments in a completely randomized design, randomized blocks or Latin square.
 #' @importFrom multcomp glht
@@ -38,8 +38,7 @@
 #' attach(cloro)
 #' respAd=c(268, 322, 275, 350, 320)
 #' a=FAT2DBC.ad(f1, f2, bloco, resp, respAd,
-#'              ylab="Number of nodules",
-#'              legend = "Stages",mcomp="sk")
+#'              ylab="Number of nodules", mcomp="sk")
 #' data=rbind(data.frame(trat=paste(f1,f2,sep = ""),bloco=bloco,resp=resp),
 #'            data.frame(trat=c("Test","Test","Test","Test","Test"),
 #'                       bloco=unique(bloco),resp=respAd))
@@ -65,7 +64,7 @@ dunnett=function(trat,
                  errorsize=1,
                  widthsize=0.2,
                  label="Response",
-                 fontfamily="sans"){
+                 family="sans"){
   trat1=factor(trat,unique(trat))
   trat=factor(trat,unique(trat))
   levels(trat1)=paste("T",1:length(levels(trat1)),sep = "")
@@ -113,8 +112,13 @@ dunnett=function(trat,
     geom_vline(xintercept = 0,lty=2,linewidth=linesize)+
     geom_label(aes(label=paste(round(Estimate,3),
                                sig)),fill="lightyellow",size=labelsize,
-               vjust=-0.5,family=fontfamily)+
-    theme(axis.text = element_text(size=textsize,family = fontfamily),
-          axis.title = element_text(size=textsize,family = fontfamily))
-  plot(graph)
+               vjust=-0.5,family=family)+
+    theme(axis.text = element_text(size=textsize,family = family),
+          axis.title = element_text(size=textsize,family = family))
+  print(graph)
+  output=list(plot=graph,
+              resp=resp,
+              trat=trat,
+              family=family,
+              control=control)
   }
