@@ -14,8 +14,7 @@
 
 
 ibarplot.double=function(analysis){
-  lista=analysis[[1]]$plot
-  data=analysis[[1]]$plot$graph
+  data=analysis$plot[[2]]$data
   media=data$media
   desvio=data$desvio
   f1=data$f1
@@ -24,17 +23,17 @@ ibarplot.double=function(analysis){
   letra1=data$letra1
   requireNamespace("ggplot2")
   ggplot(data,aes(x=f1,y=media,fill=f2))+
-    lista$theme+
-    ylab(lista$ylab)+
+    analysis$plot[[2]]$theme+
+    ylab(analysis$ylab)+
     geom_col(position = position_dodge(width = 0.9),color="black")+
     geom_errorbar(aes(ymin=media-desvio,ymax=media+desvio),
                   position = position_dodge(width = 0.9),width=0.3)+
-    geom_text(aes(y=media+desvio+lista$sup,label=paste(round(media,lista$dec),
+    geom_text(aes(y=media+desvio+analysis$sup,label=paste(round(media,analysis$dec),
                                                        toupper(letra),
                                                        tolower(letra1),sep = "")),
-              position = position_dodge(width = 0.9),family=lista$family)+
-    theme(axis.text = element_text(size = lista$textsize,family = lista$family,color="black"),
-          axis.title = element_text(size = lista$textsize,family = lista$family,color="black"),
-          legend.text = element_text(size = lista$textsize,family = lista$family,color="black"),
-          legend.title = element_text(size = lista$textsize,family = lista$family,color="black"))
+              position = position_dodge(width = 0.9),family=analysis$family)+
+    theme(axis.text = element_text(size = analysis$textsize,family = analysis$family,color="black"),
+          axis.title = element_text(size = analysis$textsize,family = analysis$family,color="black"),
+          legend.text = element_text(size = analysis$textsize,family = analysis$family,color="black"),
+          legend.title = element_text(size = analysis$textsize,family = analysis$family,color="black"))
 }
