@@ -6,7 +6,7 @@
 #' @param method.cluster Grouping method
 #' @return Returns a residual mean square ratio matrix, bar graph with ratios sorted in ascending order, or cluster analysis.
 #' @keywords Joint analysis
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @export
 #' @examples
 #' qmres=c(0.344429, 0.300542, 0.124833, 0.04531, 0.039571, 0.011812, 0.00519)
@@ -23,14 +23,14 @@ jointcluster=function(qmres,
                       information="matrix",
                       method.cluster="ward.D"){
   if(is.list(qmres)==TRUE){
-    if(nrow(qmres[[1]][[1]]$plot$anava)==2){
+    if(nrow(qmres[[1]]$anova)==2){
       qmres1=numeric(0)
       for(i in 1:length(qmres)){
-        qmres1[i]=qmres[[i]][[1]]$plot$anava$QM[2]}}
-    if(nrow(qmres[[1]][[1]]$plot$anava)==3){
+        qmres1[i]=qmres[[i]]$anova$`Mean Sq`[2]}}
+    if(nrow(qmres[[1]]$anova)==3){
       qmres1=numeric(0)
       for(i in 1:length(qmres)){
-        qmres1[i]=qmres[[i]][[1]]$plot$anava$QM[3]}}
+        qmres1[i]=qmres[[i]]$anova$`Mean Sq`[3]}}
     qmres=qmres1}
   resp=qmres
   requireNamespace("ggplot2")
