@@ -1,6 +1,6 @@
 #' Analysis: Principal components analysis
 #'
-#' @author Gabriel Danilo Shimizu
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @description This function performs principal component analysis.
 #' @return The eigenvalues and eigenvectors, the explanation percentages of each principal component, the correlations between the vectors with the principal components, as well as graphs are returned.
 #' @param data Data.frame with data set. Line name must indicate the treatment
@@ -11,8 +11,8 @@
 #' @param labelsize Label size (\emph{default} is 4)
 #' @param linesize Line size (\emph{default} is 0.8)
 #' @param repel Avoid text overlay (\emph{default} is TRUE)
-#' @param ylab Names y-axis
-#' @param xlab Names x-axis
+#' @param ylab Names y-axis (this argument uses the \emph{parse} function)
+#' @param xlab Names x-axis (this argument uses the \emph{parse} function)
 #' @param groups Define grouping
 #' @param sc Secondary axis scale ratio (\emph{default} is 1)
 #' @param font.family Font family (\emph{default} is sans)
@@ -51,6 +51,7 @@ PCA_function=function(data,
                       theme=theme_bw(),
                       label.legend="Cluster",
                       type.graph="biplot"){
+
   nVar = ncol(data)
   if(scale==TRUE){D=scale(data)}else{D=data}
   comp=length(colnames(D))
@@ -62,8 +63,9 @@ PCA_function=function(data,
       Perc=Avl/sum(Avl),
       CumPer=cumsum(Avl/sum(Avl))))
   colnames(autov)=paste("PC",1:length(Avl),sep = "")
-  if(is.na(xlab)==TRUE){xlab=paste("PC1 (",round(autov$PC1[2]*100,2),"%)",sep = "")}
-  if(is.na(ylab)==TRUE){ylab=paste("PC2 (",round(autov$PC2[2]*100,2),"%)",sep = "")}
+
+  if(is.na(xlab)==TRUE){xlab=paste("PC1 (",round(autov$PC1[2]*100,2),"%)",sep = "")}else{ylab=parse(text=gsub(" ","~",ylab))}
+  if(is.na(ylab)==TRUE){ylab=paste("PC2 (",round(autov$PC2[2]*100,2),"%)",sep = "")}else{xlab=parse(text=gsub(" ","~",xlab))}
   # Avt[,1]=Avt[,1]*-1
   Escores = as.matrix(D) %*% Avt
   Escores2 = apply(Escores, 2, function(x) (x - mean(x))/sd(x))
