@@ -1,5 +1,5 @@
 #' Graph: Interaction plot
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @description Performs an interaction graph from an output of the FAT2DIC, FAT2DBC, PSUBDIC or PSUBDBC commands.
@@ -10,6 +10,7 @@
 #' @param box_label Add box in label
 #' @param width.bar width of the error bars.
 #' @param add.errorbar Add error bars.
+#' @param family Font family
 #' @export
 #' @import ggplot2
 #' @importFrom crayon green
@@ -30,9 +31,11 @@ plot_interaction=function(a,
                           pointsize=3,
                           linesize=0.8,
                           width.bar=0.05,
-                          add.errorbar=TRUE){
-  data=a[[2]]
+                          add.errorbar=TRUE,
+                          family="sans"){
+  data=a$plot[[2]]
   requireNamespace("ggplot2")
+  requireNamespace("ggrepel")
   graph=ggplot(data$data,
                aes(x=data$data[,1],
                    y=data$data$media,
@@ -46,20 +49,18 @@ plot_interaction=function(a,
                       ymin=data$data$media-data$data$desvio),
                   width=width.bar,size=linesize)}
   graph=graph+
-    geom_line(size=linesize)
+    geom_line(linewidth=linesize)
 
   if(isTRUE(repel)==FALSE & box_label==TRUE){
     graph=graph+
-    geom_label(aes(label=data$data$numero),show.legend = FALSE,family=a[[2]]$plot$family)}
+    geom_label(aes(label=data$data$numero),show.legend = FALSE,family=family)}
   if(isTRUE(repel)==TRUE & box_label==TRUE){
-    requireNamespace("ggrepel")
     graph=graph+
-      geom_label_repel(aes(label=data$data$numero),show.legend = FALSE,family=a[[2]]$plot$family)}
+      geom_label_repel(aes(label=data$data$numero),show.legend = FALSE,family=family)}
   if(isTRUE(repel)==FALSE & box_label==FALSE){
     graph=graph+
-      geom_text(aes(label=data$data$numero),show.legend = FALSE,family=a[[2]]$plot$family)}
+      geom_text(aes(label=data$data$numero),show.legend = FALSE,family=family)}
   if(isTRUE(repel)==TRUE & box_label==FALSE){
-    requireNamespace("ggrepel")
     graph=graph+
       geom_text_repel(aes(label=data$data$numero),show.legend = FALSE)}
 
