@@ -14,7 +14,7 @@
 #' @param ic add interval of confidence
 #' @param title title
 #' @param family Font family
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @return The function returns a graph for correlation
@@ -52,8 +52,9 @@ plot_cor=function(x,y,
     theme+labs(title=title,x=xlab,y=ylab)+
     theme(axis.text = element_text(size=axis.size,
                                    color="black",family = family),
-          axis.title = element_text(family = family))+
-    annotate(geom = "text",x = -Inf,y=Inf,
+          axis.title = element_text(family = family),
+          title = element_text(family = family))+
+    annotate(geom = "text",x = -Inf,y=Inf,family=family,
              label=paste("R = ", round(corre,2), ", p-value =",
                          format(round(pvalor,3),scientific = TRUE),sep = ""),
              hjust = -0.1, vjust = 1.1)
