@@ -1,7 +1,7 @@
 #' Graph: Column, box or segment chart with observations
 #'
 #' @description The function performs the construction of graphs of boxes, columns or segments with all the observations represented in the graph.
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @param model DIC, DBC or DQL object
@@ -15,20 +15,20 @@
 plot_jitter=function(model){
   a=model
   requireNamespace("ggplot2")
-  if(a[[1]]$plot$geom=="bar"){
-  data=a[[1]]$data
+  if(a$geom=="bar"){
+  data=a$plot$data
   if(colnames(data)[3]=="respO"){
     data=data[,-1]
     colnames(data)[2]="resp"}
-  sup=a[[1]]$plot$sup
-  resp=a[[1]]$plot$response
-  trat=a[[1]]$plot$trat
-  fill=a[[1]]$plot$fill
-  theme=a[[1]]$plot$theme
-  ylab=a[[1]]$plot$ylab
-  xlab=a[[1]]$plot$xlab
-  cap=a[[1]]$labels$caption
-  textsize=a[[1]]$plot$textsize
+  sup=a$sup
+  resp=a$response
+  trat=a$trat
+  fill=a$fill
+  theme=a$plot$theme
+  ylab=a$plot$labels$y
+  xlab=a$plot$labels$x
+  cap=a$plot$labels$caption
+  textsize=a$textsize
   media=data$media
   desvio=data$desvio
   limite=data$limite
@@ -47,20 +47,20 @@ plot_jitter=function(model){
                                  color="black"))
   print(graph)
   }
-  if(a[[1]]$plot$geom=="point"){
-    data=a[[1]]$data
+  if(a$geom=="point"){
+    data=a$plot$data
     if(colnames(data)[3]=="respO"){
       data=data[,-1]
       colnames(data)[2]="resp"}
-    sup=a[[1]]$plot$sup
-    resp=a[[1]]$plot$response
-    trat=a[[1]]$plot$trat
-    fill=a[[1]]$plot$fill
-    theme=a[[1]]$plot$theme
-    ylab=a[[1]]$plot$ylab
-    xlab=a[[1]]$plot$xlab
-    cap=a[[1]]$labels$caption
-    textsize=a[[1]]$plot$textsize
+    sup=a$sup
+    resp=a$response
+    trat=a$trat
+    fill=a$fill
+    theme=a$plot$theme
+    ylab=a$plot$labels$y
+    xlab=a$plot$labels$x
+    cap=a$plot$labels$caption
+    textsize=a$textsize
     media=data$media
     desvio=data$desvio
     limite=data$limite
@@ -79,23 +79,23 @@ plot_jitter=function(model){
                                    color="black"))
     graph
   }
-  if(a[[1]]$plot$geom=="box"){
-    data1=a[[1]]$data
+  if(a$geom=="box"){
+    data1=a$plot$data
     response=data1$response
     trat=data1$trat
-    sup=a[[1]]$plot$sup
-    data=a[[1]]$plot$dadosm2
+    sup=a$sup
+    data=a$dadosm
     if(colnames(data)[3]=="respO"){
       data=data[,-1]
       colnames(data)[2]="resp"}
-    resp=a[[1]]$plot$response
-    trat=a[[1]]$plot$trat
-    fill=a[[1]]$plot$fill
-    theme=a[[1]]$plot$theme
-    ylab=a[[1]]$plot$ylab
-    xlab=a[[1]]$plot$xlab
-    cap=a[[1]]$labels$caption
-    textsize=a[[1]]$plot$textsize
+    resp=a$response
+    trat=a$trat
+    fill=a$fill
+    theme=a$plot$theme
+    ylab=a$plot$labels$y
+    xlab=a$plot$labels$x
+    cap=a$plot$labels$caption
+    textsize=a$textsize
     media=data$media
     desvio=data$desvio
     limite=data$limite
