@@ -1,5 +1,5 @@
 #' Analysis: Linear regression graph in double factorial
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @description Linear regression analysis for significant interaction of an experiment with two factors, one quantitative and one qualitative
@@ -8,11 +8,11 @@
 #' @param fator2 Numeric or complex vector with factor 2 levels
 #' @param color Graph color (\emph{default} is NA)
 #' @param grau Degree of the polynomial (1,2 or 3)
-#' @param ylab Dependent variable name (Accepts the \emph{expression}() function)
-#' @param xlab Independent variable name (Accepts the \emph{expression}() function)
+#' @param ylab Dependent variable name (this argument uses the \emph{parse} function)
+#' @param xlab Independent variable name (this argument uses the \emph{parse} function)
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param se Adds confidence interval (\emph{default} is FALSE)
-#' @param legend.title Title legend
+#' @param legend.title Title legend (this argument uses the \emph{parse} function)
 #' @param textsize Font size (\emph{default} is 12)
 #' @param family Font family (\emph{default} is sans)
 #' @param point Defines whether to plot all points ("all"), mean ("mean"), mean with standard deviation (\emph{default} - "mean_sd") or mean with standard error ("mean_se").
@@ -25,6 +25,8 @@
 #' @param n Number of decimal places for regression equations
 #' @param SSq Sum of squares of the residue
 #' @param DFres Residue freedom degrees
+#' @param print.on Print output
+#' @param plot.on Plot output
 #' @keywords regression
 #' @keywords Experimental
 #' @seealso \link{polynomial}, \link{polynomial2_color}
@@ -59,7 +61,12 @@ polynomial2=function(fator1,
                      separate=c("(\"","\")"),
                      n=NA,
                      DFres=NA,
-                     SSq=NA){
+                     SSq=NA,
+                     print.on=TRUE,
+                     plot.on=TRUE){
+
+  ylab=parse(text=gsub(" ","~",ylab))
+  xlab=parse(text=gsub(" ","~",xlab))
   if(is.na(width.bar)==TRUE){width.bar=0.05*mean(fator1)}
   requireNamespace("crayon")
   requireNamespace("ggplot2")
@@ -73,17 +80,17 @@ polynomial2=function(fator1,
   data=data.frame(fator1,fator2,resp)
   grafico=ggplot(data,aes(y=resp,x=fator1))+
     theme+
-    ylab(ylab)+
-    xlab(xlab)
+    ylab(parse(text=ylab))+
+    xlab(parse(text=xlab))
   if(point=="mean_sd"){grafico=grafico+
-    stat_summary(aes(group=fator2),fun = mean,size=linesize,
+    stat_summary(aes(group=fator2),fun = mean,linewidth=linesize,
                  geom = "errorbar",na.rm=TRUE,
                  fun.max = function(x) mean(x) + sd(x),
                  fun.min = function(x) mean(x) - sd(x),width=width.bar)+
     stat_summary(aes(shape=fator2),fun="mean",  geom="point", size=pointsize, na.rm=TRUE)}
   if(point=="mean_se"){grafico=grafico+
     stat_summary(aes(group=fator2),fun.data=mean_se, geom="errorbar",
-                 na.rm=TRUE,width=width.bar,size=linesize)+
+                 na.rm=TRUE,width=width.bar,linewidth=linesize)+
     stat_summary(aes(shape=fator2,group=fator2),fun="mean",  geom="point",na.rm=TRUE,
                  size=pointsize)}
   if(point=="mean"){grafico=grafico+
@@ -149,11 +156,11 @@ polynomial2=function(fator1,
       }
     fats=as.character(unique(Fator2)[i])
     if(adj==1){grafico=grafico+geom_smooth(data = data[fator2==levels(Fator2)[i],],aes(color=unique(fator2),lty=unique(fator2)),
-                                           method="lm", formula = y~x,na.rm=TRUE, se=se,size=linesize, show.legend=FALSE)}
+                                           method="lm", formula = y~x,na.rm=TRUE, se=se,linewidth=linesize, show.legend=FALSE)}
     if(adj==2){grafico=grafico+geom_smooth(data = data[fator2==levels(Fator2)[i],],aes(color=unique(fator2),lty=unique(fator2)),
-                                           method="lm", formula = y~x+I(x^2),na.rm=TRUE, se=se,size=linesize, show.legend=FALSE)}
+                                           method="lm", formula = y~x+I(x^2),na.rm=TRUE, se=se,linewidth=linesize, show.legend=FALSE)}
     if(adj==3){grafico=grafico+geom_smooth(data = data[fator2==levels(Fator2)[i],],aes(color=unique(fator2),lty=unique(fator2)),
-                                           method="lm", formula = y~x+I(x^2)+I(x^3),na.rm=TRUE, se=se,size=linesize, show.legend=FALSE)}
+                                           method="lm", formula = y~x+I(x^2)+I(x^3),na.rm=TRUE, se=se,linewidth=linesize, show.legend=FALSE)}
     m1=tapply(y,x,mean, na.rm=TRUE); x1=tapply(x,x,mean, na.rm=TRUE)
     if(adj==0){r2=0}
     if(adj==1){mod1=lm(m1~x1)
@@ -200,14 +207,14 @@ polynomial2=function(fator1,
     texto[[i]]=text
   }
   if(point=="mean_sd"){grafico=grafico+
-    stat_summary(aes(group=fator2),fun = mean,size=0.7,
+    stat_summary(aes(group=fator2),fun = mean,linewidth=0.7,
                  geom = "errorbar",na.rm=TRUE,
                  fun.max = function(x) mean(x) + sd(x),
                  fun.min = function(x) mean(x) - sd(x),width=width.bar)+
     stat_summary(aes(shape=fator2),fun="mean",  geom="point", size=pointsize, na.rm=TRUE)}
   if(point=="mean_se"){grafico=grafico+
     stat_summary(aes(group=fator2),fun.data=mean_se, geom="errorbar",
-                 na.rm=TRUE,width=width.bar,size=0.7)+
+                 na.rm=TRUE,width=width.bar,linewidth=0.7)+
     stat_summary(aes(shape=fator2,group=fator2),fun="mean",  geom="point",na.rm=TRUE,
                  size=pointsize)}
   if(point=="mean"){grafico=grafico+
@@ -216,14 +223,15 @@ polynomial2=function(fator1,
   if(point=="all"){grafico=grafico+
     geom_point(aes(shape=fator2),size=pointsize,na.rm = TRUE)}
 
-  cat("\n----------------------------------------------------\n")
+  if(print.on==TRUE){
+    cat("\n----------------------------------------------------\n")
   cat("Regression Models")
   cat("\n----------------------------------------------------\n")
   print(curvas)
   cat("\n----------------------------------------------------\n")
   cat("Anova")
   cat("\n----------------------------------------------------\n")
-  print(desvios,na.print=" ")
+  print(desvios,na.print=" ")}
   grafico=grafico+
     scale_linetype_manual(name=legend.title,values = color,drop=FALSE,
                                      label=parse(text=paste(
@@ -238,15 +246,13 @@ polynomial2=function(fator1,
           axis.text = element_text(size=textsize,color="black", family = family),
           axis.title = element_text(size=textsize,color="black", family = family),
           legend.position = posi,
-          legend.text=element_text(size=textsize),
+          legend.text=element_text(size=textsize,hjust = 0),
           legend.direction = "vertical",
-          legend.text.align = 0,
           legend.justification = 0)+
     labs(color=legend.title, shape=legend.title, lty=legend.title)+
     scale_color_grey(name=legend.title,
                      start = 0.12, end = 0.1,
                      label=parse(text=paste("(\"",levels(Fator2),"\")~",unlist(texto))))
-  print(grafico)
-
-  (grafico=as.list(grafico))
+  if(plot.on==TRUE){print(grafico)}
+  grafico=list(plot=grafico)
 }
