@@ -1,5 +1,5 @@
 #' Analysis: Linear regression graph in double factorial with color graph
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @description Linear regression analysis for significant interaction of an experiment with two factors, one quantitative and one qualitative
@@ -8,11 +8,11 @@
 #' @param fator2 Numeric or complex vector with factor 2 levels
 #' @param color Graph color (\emph{default} is NA)
 #' @param grau Degree of the polynomial (1,2 or 3)
-#' @param ylab Dependent variable name (Accepts the \emph{expression}() function)
-#' @param xlab Independent variable name (Accepts the \emph{expression}() function)
+#' @param ylab Dependent variable name (this argument uses the \emph{parse} function)
+#' @param xlab Independent variable name (this argument uses the \emph{parse} function)
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param se Adds confidence interval (\emph{default} is FALSE)
-#' @param legend.title Title legend
+#' @param legend.title Title legend (this argument uses the \emph{parse} function)
 #' @param textsize Font size (\emph{default} is 12)
 #' @param family Font family (\emph{default} is sans)
 #' @param point Defines whether to plot all points ("all"), mean ("mean"), mean with standard deviation ("mean_sd") or mean with standard error (\emph{default} - "mean_se").
@@ -25,6 +25,8 @@
 #' @param n Number of decimal places for regression equations
 #' @param SSq Sum of squares of the residue
 #' @param DFres Residue freedom degrees
+#' @param print.on Print output
+#' @param plot.on Plot output
 #' @keywords regression
 #' @keywords Experimental
 #' @seealso \link{polynomial}, \link{polynomial2}
@@ -59,7 +61,12 @@ polynomial2_color=function(fator1,
                            separate=c("(\"","\")"),
                            n=NA,
                            DFres=NA,
-                           SSq=NA){
+                           SSq=NA,
+                           print.on=TRUE,
+                           plot.on=TRUE){
+
+  ylab=parse(text=gsub(" ","~",ylab))
+  xlab=parse(text=gsub(" ","~",xlab))
   if(is.na(width.bar)==TRUE){width.bar=0.05*mean(fator1)}
     requireNamespace("ggplot2")
     anovaquali=anova(aov(resp~as.factor(fator1)*fator2))
@@ -73,13 +80,13 @@ polynomial2_color=function(fator1,
   data=data.frame(fator1,fator2,resp)
   grafico=ggplot(data,aes(y=resp,x=fator1))+
     theme+
-    ylab(ylab)+
-    xlab(xlab)
+    ylab(parse(text=ylab))+
+    xlab(parse(text=xlab))
   if(point=="all"){grafico=grafico+
     geom_point(aes(color=fator2),size=pointsize)}
 
   if(point=="mean_sd"){grafico=grafico+
-    stat_summary(aes(color=fator2),fun = mean,size=linesize,
+    stat_summary(aes(color=fator2),fun = mean,linewidth=linesize,
                  geom = "errorbar",
                  fun.max = function(x) mean(x) + sd(x),
                  fun.min = function(x) mean(x) - sd(x),
@@ -88,7 +95,7 @@ polynomial2_color=function(fator1,
     stat_summary(aes(color=fator2),fun = "mean",  geom="point",
                  size=pointsize,na.rm = TRUE)}
   if(point=="mean_se"){grafico=grafico+
-    stat_summary(aes(color=fator2),fun.data=mean_se, geom="errorbar",size=linesize,
+    stat_summary(aes(color=fator2),fun.data=mean_se, geom="errorbar",linewidth=linesize,
                  width=width.bar,na.rm = TRUE)+
     stat_summary(aes(color=fator2),fun="mean",  geom="point", #shape=21,fill="gray80",
                  size=pointsize,na.rm = TRUE)}
@@ -153,11 +160,11 @@ polynomial2_color=function(fator1,
     }
     fats=as.character(unique(Fator2)[i])
     if(adj==1){grafico=grafico+geom_smooth(data = data[fator2==levels(Fator2)[i],],aes(color=as.character(unique(fator2))),
-                                           method="lm", formula = y~x,size=linesize, se=se, fill="gray70")}
+                                           method="lm", formula = y~x,linewidth=linesize, se=se, fill="gray70")}
     if(adj==2){grafico=grafico+geom_smooth(data = data[fator2==levels(Fator2)[i],],aes(color=unique(fator2)),
-                                           method="lm", formula = y~x+I(x^2), size=linesize,se=se, fill="gray70")}
+                                           method="lm", formula = y~x+I(x^2), linewidth=linesize,se=se, fill="gray70")}
     if(adj==3){grafico=grafico+geom_smooth(data = data[fator2==levels(Fator2)[i],],aes(color=unique(fator2)),
-                                           method="lm", formula = y~x+I(x^2)+I(x^3), size=linesize,se=se, fill="gray70")}
+                                           method="lm", formula = y~x+I(x^2)+I(x^3), linewidth=linesize,se=se, fill="gray70")}
     m1=tapply(y,x,mean, na.rm=TRUE); x1=tapply(x,x,mean, na.rm=TRUE)
 
     if(adj==0){r2=0}
@@ -208,7 +215,7 @@ polynomial2_color=function(fator1,
     geom_point(aes(color=fator2),size=pointsize)}
 
   if(point=="mean_sd"){grafico=grafico+
-    stat_summary(aes(color=fator2),fun = mean,size=0.7,
+    stat_summary(aes(color=fator2),fun = mean,linewidth=0.7,
                  geom = "errorbar",
                  fun.max = function(x) mean(x) + sd(x),
                  fun.min = function(x) mean(x) - sd(x),
@@ -218,14 +225,14 @@ polynomial2_color=function(fator1,
                  # shape=21,fill="gray80",
                  size=pointsize,na.rm = TRUE)}
   if(point=="mean_se"){grafico=grafico+
-    stat_summary(aes(color=fator2),fun.data=mean_se, geom="errorbar",size=0.7,
+    stat_summary(aes(color=fator2),fun.data=mean_se, geom="errorbar",linewidth=0.7,
                  width=width.bar,na.rm = TRUE)+
     stat_summary(aes(color=fator2),fun="mean",  geom="point", #shape=21,fill="gray80",
                  size=pointsize,na.rm = TRUE)}
   if(point=="mean"){grafico=grafico+
     stat_summary(aes(color=fator2),fun="mean", #shape=21,
                  size=pointsize, geom="point",na.rm = TRUE)}
-
+  if(print.on==TRUE){
   cat("\n----------------------------------------------------\n")
   cat("Regression Models")
   cat("\n----------------------------------------------------\n")
@@ -233,7 +240,7 @@ polynomial2_color=function(fator1,
   cat("\n----------------------------------------------------\n")
   cat("Anova")
   cat("\n----------------------------------------------------\n")
-  print(desvios,na.print=" ")
+  print(desvios,na.print=" ")}
   grafico=grafico+scale_colour_discrete(label=parse(text=paste(
     separate[1],
     levels(Fator2),
@@ -245,9 +252,7 @@ polynomial2_color=function(fator1,
           legend.text=element_text(size=textsize),
           legend.direction = "vertical",
           legend.text.align = 0,
-          legend.justification = 0)+
-    labs(color=legend.title, shape=legend.title, lty=legend.title)
-  print(grafico)
-
-  (grafico=as.list(grafico))
+          legend.justification = 0)+labs(color=parse(text=legend.title))
+  if(plot.on==TRUE){print(grafico)}
+  grafico=list(plot=grafico)
 }
