@@ -17,16 +17,16 @@
 
 summarise_dunnett=function(variable, colnames=NA, info="sig"){
   variaveis=length(variable)
-  nomes=rownames(variable[[1]]$data)
+  nomes=rownames(variable[[1]]$plot$data)
   if(is.na(colnames[1])==TRUE){colnames=rep(paste("Var",1:variaveis))}
   datas=data.frame(matrix(rep(NA,variaveis*length(nomes)),ncol=variaveis))
   for(i in 1:variaveis){
-    if(info=="sig"){datas[,i]=variable[[i]]$data$sig}
-    if(info=="t"){datas[,i]=variable[[i]]$data$t.value}
-    if(info=="p"){datas[,i]=variable[[i]]$data$p.value}
-    if(info=="estimate"){datas[,i]=variable[[i]]$data$Estimate}
-    if(info=="IC.lower"){datas[,i]=variable[[i]]$data$IC.lwr}
-    if(info=="IC.upper"){datas[,i]=variable[[i]]$data$IC.upr}
+    if(info=="sig"){datas[,i]=variable[[i]]$plot$data$sig}
+    if(info=="t"){datas[,i]=variable[[i]]$plot$data$t.value}
+    if(info=="p"){datas[,i]=variable[[i]]$plot$data$p.value}
+    if(info=="estimate"){datas[,i]=variable[[i]]$plot$data$Estimate}
+    if(info=="IC.lower"){datas[,i]=variable[[i]]$plot$data$IC.lwr}
+    if(info=="IC.upper"){datas[,i]=variable[[i]]$plot$data$IC.upr}
   }
   rownames(datas)=nomes
   colnames(datas)=colnames
