@@ -1,5 +1,5 @@
 #' Analysis: Test for two samples
-#' @author Gabriel Danilo Shimizu, \email{shimizu@uel.br}
+#' @author Gabriel Danilo Shimizu, \email{gabrield.shimizu@gmail.com}
 #' @author Leandro Simoes Azeredo Goncalves
 #' @author Rodrigo Yudi Palhaci Marubayashi
 #' @description Test for two samples (paired and unpaired t test, paired and unpaired Wilcoxon test)
@@ -12,8 +12,8 @@
 #' @param var.equal A logical variable indicating whether to treat the two variances as being equal. If TRUE then the pooled variance is used to estimate the variance otherwise the Welch (or Satterthwaite) approximation to the degrees of freedom is used.
 #' @param conf.level Confidence level of the interval.
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
-#' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab Treatments name (Accepts the \emph{expression}() function)
+#' @param ylab Variable response name (this argument uses the \emph{parse} function)
+#' @param xlab Treatments name (this argument uses the \emph{parse} function)
 #' @param pointsize Point size
 #' @param yposition.p Position p-value in y
 #' @param xposition.p Position p-value in x
@@ -44,6 +44,9 @@ test_two=function(trat,
                   yposition.p=NA,
                   xposition.p=NA,
                   fill = "white"){
+
+  ylab=parse(text=gsub(" ","~",ylab))
+  xlab=parse(text=gsub(" ","~",xlab))
   if(test=="t" & isTRUE(paired)==FALSE){teste = t.test(
     resp ~ trat,
     correct = correct,
@@ -81,7 +84,7 @@ test_two=function(trat,
   geom_label(data=media,aes(y=media,
                             x=trat,
                             label=round(media,2)),fill="lightyellow")+
-  theme+ylab(ylab)+xlab(xlab)+
+  theme+ylab(parse(text=ylab))+xlab(parse(text=xlab))+
   theme(axis.text = element_text(size=12,color="black"))
 
   if(is.na(yposition.p)==TRUE){yposition.p=min(resp)}
@@ -95,5 +98,5 @@ test_two=function(trat,
              label=pvalor,parse=TRUE)}
   print(teste)
   print(grafico)
-  graficos=list(grafico)[[1]]
+  graficos=list(plot=grafico)[[1]]
   }
